import { TextObject, ConfirmationDialog, Option, OptionGroup } from './compositionObjects';
export declare function createButton(options: ButtonElementOptions): ButtonElement;
export declare function createDatePicker(options: DatePickerElementOptions): DatePickerElement;
export declare function createImage(options: ImageElementOptions): ImageElement;
export declare function createOverflowMenu(options: OverflowMenuOptions): OverflowMenu;
export declare function createPlainTextInput(options: PlainTextInputOptions): PlainTextInput;
export declare function createRadioButtonGroup(options: RadioButtonGroupOptions): RadioButtonGroup;
export declare function createMultiSelectMenuWithStaticOptions(options: StaticOptionsMultiSelectMenuOptions): StaticOptionsMultiSelectMenu;
export declare function createMultiSelectMenuWithExternalData(options: ExternalDataMultiSelectMenuOptions): ExternalDataMultiSelectMenu;
export declare function createMultiSelectMenuWithUserList(options: UserListMultiSelectMenuOptions): UserListMultiSelectMenu;
export declare function createMultiSelectMenuWithConversationsList(options: ConversationsListMultiSelectMenuOptions): ConversationsListMultiSelectMenu;
export declare function createMultiSelectMenuWithChannelsList(options: ChannelsListMultiSelectMenuOptions): ChannelsListMultiSelectMenu;
export declare function createSelectMenuWithStaticOptions(options: StaticOptionsSelectMenuOptions): StaticOptionsSelectMenu;
export declare function createSelectMenuWithExternalData(options: ExternalDataSelectMenuOptions): ExternalDataSelectMenu;
export declare function createSelectMenuWithUserList(options: UserListSelectMenuOptions): UserListSelectMenu;
export declare function createSelectMenuWithConversationsList(options: ConversationsListSelectMenuOptions): ConversationsListSelectMenu;
export declare function createSelectMenuWithChannelsList(options: ChannelsListSelectMenuOptions): ChannelsListSelectMenu;
export interface ButtonElementOptions {
    /**
     * A text object that defines the button's text. Can only be of type: plain_text. Maximum length for the text in this field is 75 characters.
     */
    text: TextObject;
    /**
     * An identifier for this action. You can use this when you receive an interaction payload to identify the source of the action. Should be unique among all other action_ids used elsewhere by your app. Maximum length for this field is 255 characters.
     */
    action_id: string;
    /**
     * A URL to load in the user's browser when the button is clicked. Maximum length for this field is 3000 characters. If you're using url, you'll still receive an interaction payload and will need to send an acknowledgement response.
     */
    url?: string;
    /**
     * The value to send along with the interaction payload. Maximum length for this field is 2000 characters.
     */
    value?: string;
    /**
     * Decorates buttons with alternative visual color schemes. Use this option with restraint.
     * - primary gives buttons a green outline and text, ideal for affirmation or confirmation actions. primary should only be used for one button within a set.
     * - danger gives buttons a red outline and text, and should be used when the action is destructive. Use danger even more sparingly than primary.
     *
     * If you don't include this field, the default button style will be used.
     */
    style?: 'primary' | 'danger';
    /**
     * A confirm object that defines an optional confirmation dialog after the button is clicked.
     */
    confirm?: ConfirmationDialog;
}
export interface ButtonElement extends ButtonElementOptions {
    /**
     * The type of element. In this case type is always button.
     */
    type: 'button';
}
export interface DatePickerElementOptions {
    /**
     * An identifier for the action triggered when a menu option is selected. You can use this when you receive an interaction payload to identify the source of the action. Should be unique among all other action_ids used elsewhere by your app. Maximum length for this field is 255 characters.
     */
    action_id: string;
    /**
     * A plain_text only text object that defines the placeholder text shown on the datepicker. Maximum length for the text in this field is 150 characters.
     */
    placeholder?: TextObject;
    /**
     * The initial date that is selected when the element is loaded. This should be in the format YYYY-MM-DD.
     */
    initial_date?: string;
    /**
     * A confirm object that defines an optional confirmation dialog that appears after a date is selected.
     */
    confirm?: ConfirmationDialog;
}
export interface DatePickerElement extends DatePickerElementOptions {
    /**
     * The type of element. In this case type is always datepicker.
     */
    type: 'datepicker';
}
export interface ImageElementOptions {
    /**
     * The URL of the image to be displayed.
     */
    image_url: string;
    /**
     * A plain-text summary of the image. This should not contain any markup.
     */
    alt_text: string;
}
export interface ImageElement extends ImageElementOptions {
    /**
     * The type of element. In this case type is always image.
     */
    type: 'image';
}
export interface MultiSelectMenuBaseOptions {
    /**
     * A plain_text only text object that defines the placeholder text shown on the menu. Maximum length for the text in this field is 150 characters.
     */
    placeholder: TextObject;
    /**
     * An identifier for the action triggered when a menu option is selected. You can use this when you receive an interaction payload to identify the source of the action. Should be unique among all other action_ids used elsewhere by your app. Maximum length for this field is 255 characters.
     */
    action_id: string;
    /**
     * A confirm object that defines an optional confirmation dialog that appears before the multi-select choices are submitted.
     */
    confirm?: ConfirmationDialog;
    /**
     * Specifies the maximum number of items that can be selected in the menu. Minimum number is 1.
     */
    max_selected_items?: number;
}
export interface MultiSelectMenu {
    /**
     * The type of element.
     */
    type: 'multi_static_select' | 'multi_external_select' | 'multi_users_select' | 'multi_conversations_select' | 'multi_channels_select';
}
export interface StaticOptionsMultiSelectMenuOptions extends MultiSelectMenuBaseOptions {
    /**
     * An array of option objects. Maximum number of options is 100. If option_groups is specified, this field should not be.
     */
    options?: Option[];
    /**
     * An array of option group objects. Maximum number of option groups is 100. If options is specified, this field should not be.
     */
    options_group?: OptionGroup[];
    /**
     * An array of option objects that exactly match one or more of the options within options or option_groups. These options will be selected when the menu initially loads.
     */
    initial_options?: Option[];
}
export interface StaticOptionsMultiSelectMenu extends MultiSelectMenu, StaticOptionsMultiSelectMenuOptions {
    /**
     * The type of element. In this case type is always multi_static_select.
     */
    type: 'multi_static_select';
}
export interface ExternalDataMultiSelectMenuOptions extends MultiSelectMenuBaseOptions {
    /**
     * When the typeahead field is used, a request will be sent on every character change. If you prefer fewer requests or more fully ideated queries, use the min_query_length attribute to tell Slack the fewest number of typed characters required before dispatch.
     */
    min_query_length?: number;
    /**
     * An array of option objects that exactly match one or more of the options within options or option_groups. These options will be selected when the menu initially loads.
     */
    initial_options?: Option[];
}
export interface ExternalDataMultiSelectMenu extends MultiSelectMenu, ExternalDataMultiSelectMenuOptions {
    /**
     * The type of element. In this case type is always multi_external_select.
     */
    type: 'multi_external_select';
}
export interface UserListMultiSelectMenuOptions extends MultiSelectMenuBaseOptions {
    /**
     * An array of user IDs of any valid users to be pre-selected when the menu loads.
     */
    initial_users?: string[];
}
export interface UserListMultiSelectMenu extends MultiSelectMenu, UserListMultiSelectMenuOptions {
    /**
     * The type of element. In this case type is always multi_users_select.
     */
    type: 'multi_users_select';
}
export interface ConversationsListMultiSelectMenuOptions extends MultiSelectMenuBaseOptions {
    /**
     * An array of one or more IDs of any valid conversations to be pre-selected when the menu loads.
     */
    initial_conversations?: string[];
}
export interface ConversationsListMultiSelectMenu extends MultiSelectMenu, ConversationsListMultiSelectMenuOptions {
    /**
     * The type of element. In this case type is always multi_conversations_select.
     */
    type: 'multi_conversations_select';
}
export interface ChannelsListMultiSelectMenuOptions extends MultiSelectMenuBaseOptions {
    /**
     * An array of one or more IDs of any valid public channel to be pre-selected when the menu loads.
     */
    initial_channels?: string[];
}
export interface ChannelsListMultiSelectMenu extends MultiSelectMenu, ChannelsListMultiSelectMenuOptions {
    /**
     * The type of element. In this case type is always multi_channels_select.
     */
    type: 'multi_channels_select';
}
export interface OverflowMenuOptions {
    /**
     * 	An identifier for the action triggered when a menu option is selected. You can use this when you receive an interaction payload to identify the source of the action. Should be unique among all other action_ids used elsewhere by your app. Maximum length for this field is 255 characters.
     */
    action_id: string;
    /**
     * An array of option objects to display in the menu. Maximum number of options is 5, minimum is 2.
     */
    options: Option[];
    /**
     * A confirm object that defines an optional confirmation dialog that appears after a menu item is selected.
     */
    confirm?: ConfirmationDialog;
}
export interface OverflowMenu extends OverflowMenuOptions {
    /**
     * The type of element. In this case type is always overflow.
     */
    type: 'overflow';
}
export interface PlainTextInputOptions {
    /**
     * 	An identifier for the input value when the parent modal is submitted. You can use this when you receive a view_submission payload to identify the value of the input element. Should be unique among all other action_ids used elsewhere by your app. Maximum length for this field is 255 characters.
     */
    action_id: string;
    /**
     * A plain_text only text object that defines the placeholder text shown in the plain-text input. Maximum length for the text in this field is 150 characters.
     */
    placeholder?: TextObject;
    /**
     * The initial value in the plain-text input when it is loaded.
     */
    initial_value?: string;
    /**
     * Indicates whether the input will be a single line (false) or a larger textarea (true). Defaults to false.
     */
    multiline?: boolean;
    /**
     * The minimum length of input that the user must provide. If the user provides less, they will receive an error. Maximum value is 3000.
     */
    min_length?: number;
    /**
     * The maximum length of input that the user can provide. If the user provides more, they will receive an error.
     */
    max_length?: number;
}
export interface PlainTextInput extends PlainTextInputOptions {
    /**
     * The type of element. In this case type is always plain_text_input.
     */
    type: 'plain_text_input';
}
export interface RadioButtonGroupOptions {
    /**
     * An identifier for the action triggered when the checkbox is changed. You can use this when you receive an interaction payload to identify the source of the action. Should be unique among all other action_ids used elsewhere by your app. Maximum length for this field is 255 characters.
     */
    action_id: string;
    /**
     * An array of option objects.
     */
    options: Option[];
    /**
     * An option object that exactly matches one of the options within options. This option will be selected when the radio button group initially loads.
     */
    initial_option?: Option;
    /**
     * A confirm object that defines an optional confirmation dialog that appears after clicking one of the radio buttons in this element.
     */
    confirm?: ConfirmationDialog;
}
export interface RadioButtonGroup extends RadioButtonGroupOptions {
    /**
     * The type of element. In this case type is always radio_buttons.
     */
    type: 'radio_buttons';
}
export interface SelectMenu {
    /**
     * The type of element.
     */
    type: 'static_select' | 'external_select' | 'users_select' | 'conversations_select' | 'channels_select';
}
export interface SelectMenuBaseOptions {
    /**
     * A plain_text only text object that defines the placeholder text shown on the menu. Maximum length for the text in this field is 150 characters.
     */
    placeholder: TextObject;
    /**
     * An identifier for the action triggered when a menu option is selected. You can use this when you receive an interaction payload to identify the source of the action. Should be unique among all other action_ids used elsewhere by your app. Maximum length for this field is 255 characters.
     */
    action_id: string;
    /**
     * A confirm object that defines an optional confirmation dialog that appears after a menu item is selected.
     */
    confirm?: ConfirmationDialog;
}
export interface StaticOptionsSelectMenuOptions extends SelectMenuBaseOptions {
    /**
     * An array of option objects. Maximum number of options is 100. If option_groups is specified, this field should not be.
     */
    options?: Option[];
    /**
     * An array of option group objects. Maximum number of option groups is 100. If options is specified, this field should not be.
     */
    option_groups?: OptionGroup[];
    /**
     * A single option that exactly matches one of the options within options or option_groups. This option will be selected when the menu initially loads.
     */
    initial_option?: Option;
}
export interface StaticOptionsSelectMenu extends SelectMenu, StaticOptionsSelectMenuOptions {
    /**
     * The type of element. In this case type is always static_select.
     */
    type: 'static_select';
}
export interface ExternalDataSelectMenuOptions extends SelectMenuBaseOptions {
    /**
     * A single option that exactly matches one of the options within the options or option_groups loaded from the external data source. This option will be selected when the menu initially loads.
     */
    initial_option?: Option;
    /**
     * When the typeahead field is used, a request will be sent on every character change. If you prefer fewer requests or more fully ideated queries, use the min_query_length attribute to tell Slack the fewest number of typed characters required before dispatch.
     */
    min_query_length?: number;
}
export interface ExternalDataSelectMenu extends SelectMenu, ExternalDataSelectMenuOptions {
    /**
     * The type of element. In this case type is always external_select.
     */
    type: 'external_select';
}
export interface UserListSelectMenuOptions extends SelectMenuBaseOptions {
    /**
     * The user ID of any valid user to be pre-selected when the menu loads.
     */
    initial_user?: string;
}
export interface UserListSelectMenu extends SelectMenu, UserListSelectMenuOptions {
    /**
     * The type of element. In this case type is always users_select.
     */
    type: 'users_select';
}
export interface ConversationsListSelectMenuOptions extends SelectMenuBaseOptions {
    /**
     * The ID of any valid conversation to be pre-selected when the menu loads.
     */
    initial_conversation?: string;
}
export interface ConversationsListSelectMenu extends SelectMenu, ConversationsListSelectMenuOptions {
    /**
     * The type of element. In this case type is always conversations_select.
     */
    type: 'conversations_select';
}
export interface ChannelsListSelectMenuOptions extends SelectMenuBaseOptions {
    /**
     * The ID of any valid public channel to be pre-selected when the menu loads.
     */
    initial_channel?: string;
}
export interface ChannelsListSelectMenu extends SelectMenu, ChannelsListSelectMenuOptions {
    /**
     * The type of element. In this case type is always channels_select.
     */
    type: 'channels_select';
}
//# sourceMappingURL=blockElements.d.ts.map