import { TextObject } from './compositionObjects';
import { ButtonElement, DatePickerElement, ImageElement, MultiSelectMenu, OverflowMenu, PlainTextInput, RadioButtonGroup, SelectMenu } from './blockElements';
export { ButtonElement, DatePickerElement, ImageElement, MultiSelectMenu, OverflowMenu, PlainTextInput, RadioButtonGroup, SelectMenu } from './blockElements';
export { TextObject, ConfirmationDialog, Option, OptionGroup } from './compositionObjects';
export declare function createSectionBlock(options: SectionOptions): SectionBlock;
export declare function createDividerBlock(options?: DividerOptions): DividerBlock;
export declare function createImageBlock(options: ImageOptions): ImageBlock;
export declare function createActionsBlock(options: ActionsOptions): ActionsBlock;
export declare function createContextBlock(options: ContextOptions): ContextBlock;
export declare function createInputBlock(options: InputOptions): InputBlock;
export declare function createFileBlock(options: FileOptions): FileBlock;
export declare function createHeaderBlock(options: HeaderOptions): HeaderBlock;
export interface BlockKitElement {
    type: 'section' | 'divider' | 'image' | 'actions' | 'context' | 'input' | 'file' | 'header';
}
export interface SectionOptions {
    /**
     * The text for the block, in the form of a text object. Maximum length for the text in this field is 3000 characters. This field is not required if a valid array of fields objects is provided instead.
     */
    text?: TextObject;
    /**
     * A string acting as a unique identifier for a block. You can use this block_id when you receive an interaction payload to identify the source of the action. If not specified, one will be generated. Maximum length for this field is 255 characters. block_id should be unique for each message and each iteration of a message. If a message is updated, use a new block_id.
     */
    block_id?: string;
    /**
     * An array of text objects. Any text objects included with fields will be rendered in a compact format that allows for 2 columns of side-by-side text. Maximum number of items is 10. Maximum length for the text in each item is 2000 characters.
     */
    fields?: TextObject[];
    /**
     * One of the available element objects.
     */
    accessory?: ButtonElement | DatePickerElement | ImageElement | MultiSelectMenu | OverflowMenu | PlainTextInput | RadioButtonGroup | SelectMenu;
}
export interface SectionBlock extends BlockKitElement, SectionOptions {
    /**
     * The type of block. For a section block, type will always be section.
     */
    type: 'section';
}
export interface DividerOptions {
    /**
     * A string acting as a unique identifier for a block. You can use this block_id when you receive an interaction payload to identify the source of the action. If not specified, one will be generated. Maximum length for this field is 255 characters.
     */
    block_id?: string;
}
export interface DividerBlock extends BlockKitElement, DividerOptions {
    /**
     * 	The type of block. For a divider block, type is always divider.
     */
    type: 'divider';
}
export interface ImageOptions {
    /**
     * The URL of the image to be displayed. Maximum length for this field is 3000 characters.
     */
    image_url: string;
    /**
     * A plain-text summary of the image. This should not contain any markup. Maximum length for this field is 2000 characters.
     */
    alt_text: string;
    /**
     * An optional title for the image in the form of a text object that can only be of type: plain_text. Maximum length for the text in this field is 2000 characters.
     */
    title?: TextObject;
    /**
     * 	A string acting as a unique identifier for a block. You can use this block_id when you receive an interaction payload to identify the source of the action. If not specified, a block_id will be generated. Maximum length for this field is 255 characters.
     */
    block_id?: string;
}
export interface ImageBlock extends BlockKitElement, ImageOptions {
    /**
     * The type of block. For an image block, type is always image.
     */
    type: 'image';
}
export interface ActionsOptions {
    /**
     * An array of interactive element objects - buttons, select menus, overflow menus, or date pickers. There is a maximum of 5 elements in each action block.
     */
    elements: (ButtonElement | DatePickerElement | OverflowMenu | PlainTextInput | RadioButtonGroup | SelectMenu)[];
    /**
     * A string acting as a unique identifier for a block. You can use this block_id when you receive an interaction payload to identify the source of the action. If not specified, a block_id will be generated. Maximum length for this field is 255 characters.
     */
    block_id?: string;
}
export interface ActionsBlock extends BlockKitElement, ActionsOptions {
    /**
     * The type of block. For an actions block, type is always actions.
     */
    type: 'actions';
}
export interface ContextOptions {
    /**
     * An array of image elements and text objects. Maximum number of items is 10.
     */
    elements: (ImageElement | TextObject)[];
    /**
     * A string acting as a unique identifier for a block. You can use this block_id when you receive an interaction payload to identify the source of the action. If not specified, a block_id will be generated. Maximum length for this field is 255 characters.
     */
    block_id?: string;
}
export interface ContextBlock extends BlockKitElement, ContextOptions {
    /**
     * The type of block. For a context block, type is always context.
     */
    type: 'context';
}
export interface InputOptions {
    /**
     * 	A label that appears above an input element in the form of a text object that must have type of plain_text. Maximum length for the text in this field is 2000 characters.
     */
    label: TextObject;
    /**
     * An plain-text input element, a select menu element, a multi-select menu element, or a datepicker.
     */
    element: DatePickerElement | MultiSelectMenu | PlainTextInput | RadioButtonGroup | SelectMenu;
    /**
     * A string acting as a unique identifier for a block. You can use this block_id when you receive an interaction payload to identify the source of the action. If not specified, one will be generated. Maximum length for this field is 255 characters. block_id should be unique for each message and each iteration of a message. If a message is updated, use a new block_id.
     */
    block_id?: string;
    /**
     * An optional hint that appears below an input element in a lighter grey. It must be a a text object with a type of plain_text. Maximum length for the text in this field is 2000 characters.
     */
    hint?: TextObject;
    /**
     * A boolean that indicates whether the input element may be empty when a user submits the modal. Defaults to false.
     */
    optional?: boolean;
    /**
     * A boolean that indicates whether or not the use of elements in this block should dispatch a block_actions payload. Defaults to false.
     */
    dispatch_action?: boolean;
}
export interface InputBlock extends BlockKitElement, InputOptions {
    /**
     * The type of block. For an input block, type is always input.
     */
    type: 'input';
}
export interface FileOptions {
    /**
     * The external unique ID for this file.
     */
    external_id: string;
    /**
     * At the moment, source will always be remote for a remote file.
     */
    source: string;
    /**
     * 	A string acting as a unique identifier for a block. You can use this block_id when you receive an interaction payload to identify the source of the action. If not specified, a block_id will be generated. Maximum length for this field is 255 characters.
     */
    block_id?: string;
}
export interface FileBlock extends BlockKitElement, FileOptions {
    /**
     * The type of block. For a file block, type is always file.
     */
    type: 'file';
}
export interface HeaderOptions {
    /**
     * The text for the block, in the form of a plain_text text object. Maximum length for the text in this field is 150 characters.
     */
    text: TextObject;
    /**
     * A string acting as a unique identifier for a block. You can use this block_id when you receive an interaction payload to identify the source of the action. If not specified, a block_id will be generated. Maximum length for this field is 255 characters.
     */
    block_id?: string;
}
export interface HeaderBlock extends BlockKitElement, HeaderOptions {
    /**
     * The type of block. For this block, type will always be header.
     */
    type: 'header';
}
//# sourceMappingURL=index.d.ts.map