import { ErrorStrategyHandlers, SlackError } from '../handled-api/common';
import { AnythingButUndefined, TooManyRequestsError, HttpError, UnexpectedError } from '@avst-api/commons';
interface MappedSlackError {
    errors: string[];
    handler: (slackError: string, attempt: number) => AnythingButUndefined;
}
export declare class ErrorStrategyBuilder {
    private options;
    private slackErrors;
    constructor(options?: ErrorStrategyHandlers, slackErrors?: MappedSlackError[]);
    static create(): ErrorStrategyBuilder;
    /**
     * Maps error handler for specific Slack error(s). You can specify it multiple times for different behaviours. Last error handler for matching Slack error is applied.
     * Return the value you whish to continue with, or return 'retry()' for retrying the request, or return 'continuePropagation()' for allowing the error to propagate.
     * @param handler Handler to execute when matching Slack error is returned.
     * @param slackErrors One or many Slack errors to match.
     */
    mapSlackError(handler: (slackError: string, attempt: number) => AnythingButUndefined, ...slackErrors: string[]): ErrorStrategyBuilder;
    /**
     * Error handler for any Slack Error. Return the value you whish to continue with, or return 'retry()' for retrying the request, or return 'continuePropagation()' for allowing the error to propagate.
     */
    slackError(handler: (error: SlackError, attempt: number) => AnythingButUndefined): ErrorStrategyBuilder;
    /**
     * Error handler for HTTP code 429 (Too Many Requests). Return the value you whish to continue with, or return 'retry()' for retrying the request, or return 'continuePropagation()' for allowing the error to propagate.
     */
    http429Error(handler: (error: TooManyRequestsError<any>, attempt: number) => AnythingButUndefined): ErrorStrategyBuilder;
    /**
     * Error handler for any invalid HTTP code (anything other than in 200 and 300 range). Return the value you whish to continue with, or return 'retry()' for retrying the request, or return 'continuePropagation()' for allowing the error to propagate.
     */
    httpAnyError(handler: (error: HttpError<any>, attempt: number) => AnythingButUndefined): ErrorStrategyBuilder;
    /**
     * Error handler for unexpected error, usually either network error or JSON parsing error. Return the value you whish to continue with, or return 'retry()' for retrying the request, or return 'continuePropagation()' for allowing the error to propagate.
     */
    unexpectedError(handler: (error: UnexpectedError, attempt: number) => AnythingButUndefined): ErrorStrategyBuilder;
    /**
     * Error handler for any error. Return the value you whish to continue with, or return 'retry()' for retrying the request, or return 'continuePropagation()' for allowing the error to propagate.
     */
    anyError(handler: (error: SlackError | HttpError<any> | UnexpectedError, attempt: number) => AnythingButUndefined): ErrorStrategyBuilder;
    /**
     * Retry when HTTP request is being rate limited (429 response).
     * @param total How many times to re-try. Set to -1 to retry indefinitely (default).
     * @param delay How long to delay before re-trying again, in milliseconds. Set to -1 to try to follow 'Retry-After' header value (default).
     * @param delayIncrease Delay to increase per each unsuccessful re-try, in milliseconds. Default: 1 second.
     */
    retryOnRateLimiting(total?: number, delay?: number, delayIncrease?: number): ErrorStrategyBuilder;
    /**
     * Retry on any HTTP error.
     * @param total How many times to re-try. Set to -1 to retry indefinitely. Default: 3.
     * @param delay How long to delay before re-trying again, in milliseconds. Set to -1 to try to follow 'Retry-After' header value. Default: 1 second.
     * @param delayIncrease Delay to increase per each unsuccessful re-try, in milliseconds. Default: 1 second.
     */
    retryOnHttpError(total?: number, delay?: number, delayIncrease?: number): ErrorStrategyBuilder;
    /**
     * Retry on any failure.
     * @param total How many times to re-try. Set to -1 to retry indefinitely. Default: 3.
     * @param delay How long to delay before re-trying again, in milliseconds. Set to -1 to try to follow 'Retry-After' header value. Default: 1 second.
     * @param delayIncrease Delay to increase per each unsuccessful re-try, in milliseconds. Default: 1 second.
     */
    retryOnAnyError(total?: number, delay?: number, delayIncrease?: number): ErrorStrategyBuilder;
    /**
     * Builds the error strategy object.
     */
    build(): ErrorStrategyHandlers;
}
export {};
//# sourceMappingURL=errorStrategy.d.ts.map