import { getRetryErrorHandler, continuePropagation } from '@avst-api/commons';
export class ErrorStrategyBuilder {
    constructor(options = {}, slackErrors = []) {
        this.options = options;
        this.slackErrors = slackErrors;
    }
    static create() {
        return new ErrorStrategyBuilder();
    }
    /**
     * Maps error handler for specific Slack error(s). You can specify it multiple times for different behaviours. Last error handler for matching Slack error is applied.
     * Return the value you whish to continue with, or return 'retry()' for retrying the request, or return 'continuePropagation()' for allowing the error to propagate.
     * @param handler Handler to execute when matching Slack error is returned.
     * @param slackErrors One or many Slack errors to match.
     */
    mapSlackError(handler, ...slackErrors) {
        this.slackErrors.push({
            handler,
            errors: slackErrors
        });
        return new ErrorStrategyBuilder(this.options, this.slackErrors);
    }
    /**
     * Error handler for any Slack Error. Return the value you whish to continue with, or return 'retry()' for retrying the request, or return 'continuePropagation()' for allowing the error to propagate.
     */
    slackError(handler) {
        this.options.handleSlackError = handler;
        return new ErrorStrategyBuilder(this.options, this.slackErrors);
    }
    /**
     * Error handler for HTTP code 429 (Too Many Requests). Return the value you whish to continue with, or return 'retry()' for retrying the request, or return 'continuePropagation()' for allowing the error to propagate.
     */
    http429Error(handler) {
        this.options.handleHttp429Error = handler;
        return new ErrorStrategyBuilder(this.options, this.slackErrors);
    }
    /**
     * Error handler for any invalid HTTP code (anything other than in 200 and 300 range). Return the value you whish to continue with, or return 'retry()' for retrying the request, or return 'continuePropagation()' for allowing the error to propagate.
     */
    httpAnyError(handler) {
        this.options.handleHttpAnyError = handler;
        return new ErrorStrategyBuilder(this.options, this.slackErrors);
    }
    /**
     * Error handler for unexpected error, usually either network error or JSON parsing error. Return the value you whish to continue with, or return 'retry()' for retrying the request, or return 'continuePropagation()' for allowing the error to propagate.
     */
    unexpectedError(handler) {
        this.options.handleUnexpectedError = handler;
        return new ErrorStrategyBuilder(this.options, this.slackErrors);
    }
    /**
     * Error handler for any error. Return the value you whish to continue with, or return 'retry()' for retrying the request, or return 'continuePropagation()' for allowing the error to propagate.
     */
    anyError(handler) {
        this.options.handleAnyError = handler;
        return new ErrorStrategyBuilder(this.options, this.slackErrors);
    }
    /**
     * Retry when HTTP request is being rate limited (429 response).
     * @param total How many times to re-try. Set to -1 to retry indefinitely (default).
     * @param delay How long to delay before re-trying again, in milliseconds. Set to -1 to try to follow 'Retry-After' header value (default).
     * @param delayIncrease Delay to increase per each unsuccessful re-try, in milliseconds. Default: 1 second.
     */
    retryOnRateLimiting(total = -1, delay = -1, delayIncrease = 1000) {
        return this.http429Error(getRetryErrorHandler(total, delay, delayIncrease));
    }
    /**
     * Retry on any HTTP error.
     * @param total How many times to re-try. Set to -1 to retry indefinitely. Default: 3.
     * @param delay How long to delay before re-trying again, in milliseconds. Set to -1 to try to follow 'Retry-After' header value. Default: 1 second.
     * @param delayIncrease Delay to increase per each unsuccessful re-try, in milliseconds. Default: 1 second.
     */
    retryOnHttpError(total = 3, delay = 1000, delayIncrease = 1000) {
        return this.httpAnyError(getRetryErrorHandler(total, delay, delayIncrease));
    }
    /**
     * Retry on any failure.
     * @param total How many times to re-try. Set to -1 to retry indefinitely. Default: 3.
     * @param delay How long to delay before re-trying again, in milliseconds. Set to -1 to try to follow 'Retry-After' header value. Default: 1 second.
     * @param delayIncrease Delay to increase per each unsuccessful re-try, in milliseconds. Default: 1 second.
     */
    retryOnAnyError(total = 3, delay = 1000, delayIncrease = 1000) {
        return this.anyError(getRetryErrorHandler(total, delay, delayIncrease));
    }
    /**
     * Builds the error strategy object.
     */
    build() {
        if (this.slackErrors.length > 0) {
            const originalSlackErrorHandler = this.options.handleSlackError;
            this.options.handleSlackError = (slackError, attempt) => {
                return slackError.response.json()
                    .then(({ error }) => {
                    for (const mappedError of this.slackErrors.reverse()) {
                        if (mappedError.errors.map(e => e.trim().toLowerCase()).indexOf(error.trim().toLowerCase()) != -1) {
                            return mappedError.handler(error, attempt);
                        }
                    }
                    if (originalSlackErrorHandler) {
                        originalSlackErrorHandler(slackError, attempt);
                    }
                    return continuePropagation();
                });
            };
        }
        return this.options;
    }
}
