export declare type SlackPayload = SlackSlashCommandPayload | SlackMessageShortcutPayload | SlackGlobalShortcutPayload | SlackComponentActionPayload | SlackSubscribedEventPayload | SlackModalPayload;
/**
 * Your slash command was invoked.
 */
export interface SlackSlashCommandPayload {
    /**
     * The ID of the channel where the user was in Slack when they triggered your app's command.
     */
    channel_id: string;
    /**
     * The plain text name of the channel where the user was in Slack when they triggered your app's command, but as always you should only rely on the IDs as the names might change arbitrarily.
     */
    channel_name: string;
    /**
     * The command that was typed in to trigger this request. This value can be useful if you want to use a single Request URL to service multiple Slash Commands, as it lets you tell them apart.
     */
    command: string;
    /**
     * A temporary webhook URL that you can use to generate messages responses.
     */
    response_url: string;
    team_domain: string;
    /**
     * The ID of the workspace where the user was in Slack when they triggered your app's command.
     */
    team_id: string;
    /**
     * This is the part of the Slash Command after the command itself, and it can contain absolutely anything that the user might decide to type. It is common to use this text parameter to provide extra context for the command.
     * You can prompt users to adhere to a particular format by showing them in the Usage Hint field when creating a command.
     */
    text: string;
    /**
     * This is a verification token, a deprecated feature that you shouldn't use any more. It was used to verify that requests were legitimately being sent by Slack to your app, but you should use the signed secrets functionality to do this instead.
     */
    token: string;
    /**
     * A short-lived ID that will let your app open a modal.
     */
    trigger_id: string;
    /**
     * The ID of the user who triggered the command.
     */
    user_id: string;
    /**
     * The plain text name of the user who triggered the command. As above, do not rely on this field as it is being phased out, use the user_id instead.
     */
    user_name: string;
}
/**
 * Received when a user uses message shortcut created by the receiving app.
 */
export interface SlackMessageShortcutPayload {
    /**
     * A deprecated verification token feature. You should validate the request payload, however, and the best way to do so is to use the signing secret provided to your app.
     */
    token: string;
    /**
     * An ID that you defined when creating the shortcut.
     */
    callback_id: string;
    /**
     * Helps identify which type of interactive component sent the payload.
     */
    type: 'message_action';
    /**
     * A temporary ID generated for the interaction in your app. This value can be used to open modals.
     */
    trigger_id: string;
    /**
     * A temporary webhook that can be used to send messages in response to interactions.
     */
    response_url: string;
    /**
     * The workspace (what we used to call a team) that the shortcut was initiated in.
     */
    team: {
        id: string;
        domain: string;
    };
    /**
     * The channel that the source message was located in.
     */
    channel: {
        id: string;
        name: string;
    };
    /**
     * The user who initiated the shortcut.
     */
    user: {
        id: string;
        name: string;
    };
    /**
     * The message that the user initiated the shortcut from. This will include the full structure of the message.
     */
    message: {
        type: string;
        user: string;
        ts: string;
        text: string;
        [keyname: string]: any;
    };
    actions?: Array<Record<string, any>>;
}
/**
 * Received when a user uses global shortcut created by the receiving app.
 */
export interface SlackGlobalShortcutPayload {
    /**
     * A deprecated verification token feature. You should validate the request payload, however, and the best way to do so is to use the signing secret provided to your app.
     */
    token: string;
    /**
     * 	An ID that you defined when creating the shortcut.
     */
    callback_id: string;
    /**
     * Helps identify which type of interactive component sent the payload.
     */
    type: 'shortcut';
    /**
     * A temporary ID generated for the interaction in your app. This value can be used to open modals.
     */
    trigger_id: string;
    action_ts: string;
    /**
     * The workspace (what we used to call a team) that the shortcut was initiated in.
     */
    team: {
        id: string;
        domain: string;
    };
    /**
     * The user who initiated the shortcut.
     */
    user: {
        id: string;
        name: string;
    };
    actions?: Array<Record<string, any>>;
}
/**
 * Received when a user interacts with a Block Kit interactive component.
 */
export interface SlackComponentActionPayload {
    /**
     * Helps identify which type of interactive component sent the payload; An interactive element in a block will have a type of block_actions, whereas an interactive element in a message attachment will have a type of interactive_message.
     */
    type: 'block_actions' | 'interactive_message';
    api_app_id: string;
    callback_id?: string;
    /**
     * The workspace where the interaction was triggered.
     */
    team: {
        id: string;
        domain: string;
    };
    /**
     * The channel where the interaction was triggered.
     */
    channel: {
        id: string;
        name: string;
    };
    /**
     * The user who interacted to trigger this request.
     */
    user: {
        id: string;
        name?: string;
        username?: string;
        team_id?: string;
    };
    /**
     * Represents a deprecated verification token feature. You should validate the request payload, however, and the best way to do so is to use the signing secret provided to your app.
     */
    token: string;
    /**
     * A short-lived webhook that can be used to send messages in response to interactions.
     */
    response_url: string;
    /**
     * A short-lived ID that can be used to open modals.
     */
    trigger_id: string;
    /**
     * Contains data from the specific interactive component that was used. App surfaces can contain blocks with multiple interactive components, and each of those components can have multiple values selected by users. Combine the fields within actions to help provide the full context of the interaction.
     */
    actions: {
        type: string;
        /**
         * Identifies the interactive component itself. Some blocks can contain multiple interactive components, so the block_id alone may not be specific enough to identify the source component.
         */
        action_id: string;
        /**
         * Identifies the block within a surface that contained the interactive component that was used.
         */
        block_id: string;
        /**
         * Set by your app when you composed the blocks, this is the value that was specified in the interactive component when an interaction happened. For example, a select menu will have multiple possible values depending on what the user picks from the menu, and value will identify the chosen option.
         */
        value?: string;
        action_ts: string;
        [keyname: string]: any;
    }[];
    /**
     * The source app surface the user initiated the interaction from. This will include the full state of the view within a modal or Home tab. If the source was an ephemeral message, this field will not be included.
     */
    view?: Record<string, any>;
    /**
     * 	The source app surface the user initiated the interaction from. This will include the full state of the message within a modal or Home tab. If the source was an ephemeral message, this field will not be included.
     */
    message?: Record<string, any>;
    container?: Record<string, any>;
}
export interface SlackSubscribedEventPayload {
    /**
     *	The shared-private callback token that authenticates this callback to the application as having come from Slack. Match this against what you were given when the subscription was created. If it does not match, do not process the event and discard it.
     */
    token: string;
    /**
     * The unique identifier for the workspace/team where this event occurred.
     */
    team_id: string;
    /**
     * 	The unique identifier for the application this event is intended for. Your application's ID can be found in the URL of the your application console. If your Request URL manages multiple applications, use this field along with the token field to validate and route incoming requests.
     */
    api_app_id: string;
    /**
     * Contains the inner set of fields representing the event that's happening.
     */
    event: {
        /**
         * The specific name of the event described by its adjacent fields. This field is included with every inner event type.
         */
        type: string;
        /**
         * The timestamp of the event. The combination of event_ts, team_id, user_id, or channel_id is intended to be unique. This field is included with every inner event type.
         */
        event_ts: string;
        [keyname: string]: any;
    };
    /**
     * This reflects the type of callback you're receiving. Typically, that is event_callback. You may encounter url_verification during the configuration process. The `event` fields "inner event" will also contain a type field indicating which event type lurks within.
     */
    type: string;
    /**
     * A unique identifier for this specific event, globally unique across all workspaces.
     */
    event_id: string;
    /**
     * The epoch timestamp in seconds indicating when this event was dispatched.
     */
    event_time: number;
    /**
     * An array of string-based User IDs. Each member of the collection represents a user that has installed your application/bot and indicates the described event would be visible to those users. You'll receive a single event for a piece of data intended for multiple users in a workspace, rather than a message per user.
     */
    authed_users: string[];
}
export interface SlackModalPayload {
    type: string;
    team: {
        id: string;
        domain: string;
    };
    user: {
        id: string;
        name?: string;
    };
    api_app_id?: string;
    view: {
        id: string;
        type: string;
        callback_id: string;
        title: Record<string, any>;
        submit?: Record<string, any>;
        blocks?: [{
            [keyname: string]: any;
        }];
        private_metadata?: string;
        state?: {
            values?: Record<string, any>;
        };
        hash?: string;
    };
    trigger_id?: string;
    response_urls?: any[];
    is_cleared?: boolean;
}
//# sourceMappingURL=events.d.ts.map