import { AnythingButUndefined, TooManyRequestsError, HttpError, RequestValidationError, UnexpectedError, Response } from '@avst-api/commons';
import { ErrorStrategyBuilder } from '../builders/errorStrategy';
export interface ErrorStrategyOption {
    errorStrategy?: ErrorStrategyHandlers | null;
}
export interface AssistedErrorStrategyOption {
    errorStrategy?: ErrorStrategyHandlers | AssistedErrorStrategyFunction | null;
}
export declare type AssistedErrorStrategyFunction = (builder: ErrorStrategyBuilder) => ErrorStrategyBuilder | ErrorStrategyHandlers;
export interface ErrorStrategyHandlers {
    /**
     * Error handler for any Slack error. Return the value you whish to continue with, or return 'retry()' for retrying the request, or return 'continuePropagation()' for allowing the error to propagate.
     * @param error
     * @param attempt
     */
    handleSlackError?(error: SlackError, attempt: number): AnythingButUndefined;
    /**
     * Error handler for HTTP code 429 (Too Many Requests). Return the value you whish to continue with, or return 'retry()' for retrying the request, or return 'continuePropagation()' for allowing the error to propagate.
     * @param error Error that happened.
     * @param attempt How many times this request has already been executed. Starts with 1 and increases after each 'retry()'.
     */
    handleHttp429Error?(error: TooManyRequestsError<any>, attempt: number): AnythingButUndefined;
    /**
     * Error handler for any invalid HTTP code (anything other than in 200 and 300 range). Return the value you whish to continue with, or return 'retry()' for retrying the request, or return 'continuePropagation()' for allowing the error to propagate.
     * @param error Error that happened.
     * @param attempt How many times this request has already been executed. Starts with 1 and increases after each 'retry()'.
     */
    handleHttpAnyError?(error: HttpError<any>, attempt: number): AnythingButUndefined;
    /**
     * Error handler for unexpected error, usually either network error or JSON parsing error. Return the value you whish to continue with, or return 'retry()' for retrying the request, or return 'continuePropagation()' for allowing the error to propagate.
     * @param error Error that happened.
     * @param attempt How many times this request has already been executed. Starts with 1 and increases after each 'retry()'.
     */
    handleUnexpectedError?(error: UnexpectedError, attempt: number): AnythingButUndefined;
    /**
     * Error handler for any error. Return the value you whish to continue with, or return 'retry()' for retrying the request, or return 'continuePropagation()' for allowing the error to propagate.
     * @param error Error that happened.
     * @param attempt How many times this request has already been executed. Starts with 1 and increases after each 'retry()'.
     */
    handleAnyError?(error: SlackError | HttpError<any> | RequestValidationError | UnexpectedError, attempt: number): AnythingButUndefined;
}
export declare class SlackError<Err = GenericSlackErrorResponse> extends Error {
    response: Response<Err>;
    name: string;
    constructor(response: Response<Err>, message: string);
}
export interface GenericSlackErrorResponse {
    ok: false;
    error: string;
}
export declare function executeRequest<Res, HRes, Err>(promise: () => Promise<Response<any>>, errorHandlers: ErrorStrategyHandlers, attempt?: number): Promise<Res>;
export declare function injectBuilders(options: any): any;
//# sourceMappingURL=common.d.ts.map