import { TooManyRequestsError, HttpError, RequestValidationError, UnexpectedError, RetryRequested, PropagationRequested } from '@avst-api/commons';
import { ErrorStrategyBuilder } from '../builders/errorStrategy';
// TODO: get type inference working in try/catch
export class SlackError extends Error {
    constructor(response, message) {
        super(message);
        this.response = response;
        this.name = 'SlackError';
    }
}
function delay(ms) {
    return new Promise(resolve => {
        if (ms === 0) {
            resolve();
        }
        else {
            setTimeout(() => resolve(), ms);
        }
    });
}
export async function executeRequest(promise, errorHandlers, attempt = 1) {
    const currentStack = new Error().stack;
    const errorHandlersCopy = errorHandlers ? Object.assign({}, errorHandlers) : undefined; // Creating a shallow copy as the error handling methods will be progressively deleted when propagation is requested
    try {
        const res = await promise();
        if (res.ok) {
            const body = await res.json();
            if (body) {
                if (body.ok) {
                    return body;
                }
                else {
                    throw new SlackError(res, `Slack error: ${body.error}`);
                }
            }
            else {
                return undefined;
            }
        }
        else {
            const err = mapStatusCodeToError(res);
            if (currentStack && err.stack) {
                err.stack = currentStack.replace('Error', err.stack.split('\n')[0]);
            }
            throw err;
        }
    }
    catch (originalError) {
        try {
            return handleError(originalError, attempt, errorHandlersCopy);
        }
        catch (error) {
            if (error instanceof RetryRequested) {
                await delay(error.delay);
                return executeRequest(promise, errorHandlers, ++attempt);
            }
            if (error instanceof PropagationRequested) {
                throw originalError;
            }
            throw error;
        }
    }
}
export function injectBuilders(options) {
    if (options && options.errorStrategy && typeof options.errorStrategy === 'function') {
        const response = options.errorStrategy(ErrorStrategyBuilder.create());
        if (response instanceof ErrorStrategyBuilder) {
            options.errorStrategy = response.build();
        }
        else {
            options.errorStrategy = response;
        }
    }
    return options;
}
function handleError(e, attempt, errorHandlers) {
    let error;
    if (!(e instanceof SlackError || e instanceof HttpError || e instanceof RequestValidationError)) {
        error = new UnexpectedError(e, e.toString ? e.toString() : 'Unexpected Error');
    }
    else {
        error = e;
    }
    let errorHandler = undefined;
    try {
        if (errorHandlers) {
            const { handleSlackError, handleHttp429Error, handleHttpAnyError, handleUnexpectedError, handleAnyError } = errorHandlers;
            if (error instanceof SlackError && handleSlackError) {
                errorHandler = 'handleSlackError';
                return handleErrorStrategyResponse(handleSlackError, error, attempt);
            }
            if (error instanceof HttpError) {
                if (error instanceof TooManyRequestsError && handleHttp429Error) {
                    errorHandler = 'handleHttp429Error';
                    return handleErrorStrategyResponse(handleHttp429Error, error, attempt);
                }
                if (handleHttpAnyError) {
                    errorHandler = 'handleHttpAnyError';
                    return handleErrorStrategyResponse(handleHttpAnyError, error, attempt);
                }
            }
            if (error instanceof UnexpectedError && handleUnexpectedError) {
                errorHandler = 'handleUnexpectedError';
                return handleErrorStrategyResponse(handleUnexpectedError, error, attempt);
            }
            if (handleAnyError) {
                errorHandler = 'handleAnyError';
                return handleErrorStrategyResponse(handleAnyError, error, attempt);
            }
        }
    }
    catch (e) {
        if (e instanceof RetryRequested) {
            throw e;
        }
        if (e instanceof PropagationRequested) {
            if (e.skipErrorStrategyPropagation) {
                throw e;
            }
            if (errorHandler && errorHandlers) {
                delete errorHandlers[errorHandler]; // Delete the current callback method so when a propagation is allowed to progress then this error handler cannot be reached any longer
                return handleError(error, attempt, errorHandlers);
            }
        }
        return Promise.reject(e);
    }
    return Promise.reject(error);
}
function handleErrorStrategyResponse(callback, error, attempt) {
    const response = callback(error, attempt);
    if (response instanceof RetryRequested) {
        throw response;
    }
    if (response instanceof PropagationRequested) {
        throw response;
    }
    return Promise.resolve(response);
}
function mapStatusCodeToError(response) {
    const fetchId = response.headers.get('x-hzn-fetch-id');
    switch (response.status) {
        case 429:
            return new TooManyRequestsError(response, getMessage(response.status, fetchId));
        default:
            return new HttpError(response, getMessage(response.status, fetchId));
    }
}
function getMessage(statusCode, fetchId) {
    let message = `Unexpected HTTP response: ${statusCode}`;
    if (fetchId) {
        message += ` - Fetch ID: ${fetchId}`;
    }
    return message;
}
