/// <reference types="runtime" />
import { Admin } from "./types/admin";
import { View } from "./types/view";
import { User } from "./types/user";
import { Reminders } from "./types/reminders";
import { Pins } from "./types/pins";
import { Bot } from "./types/bot";
import { Chat } from "./types/chat";
import { Conversation } from "./types/conversation";
import { Dialog } from "./types/dialog";
import { Dnd } from "./types/dnd";
import { Emoji } from "./types/emoji";
import { File } from "./types/file";
import { Reaction } from "./types/reaction";
import { Search } from "./types/search";
import { Team } from "./types/team";
import { UserGroup } from "./types/userGroup";
import { Reply } from "./types/reply";
import { AssistedErrorStrategyFunction, AssistedErrorStrategyOption, ErrorStrategyHandlers } from "./handled-api/common";
interface ConnectionOptions extends AssistedErrorStrategyOption {
}
export declare namespace SlackConnection {
    function connect(connection: string, options?: ConnectionOptions): SlackInstance;
}
export declare class SlackInstance {
    All: AllGroup;
    AllUser: AllUserGroup;
    AllBot: AllBotGroup;
    private connection;
    Admin: AdminGroup;
    View: ViewGroup;
    User: UserGroup;
    Reminders: RemindersGroup;
    Pins: PinsGroup;
    Bot: BotGroup;
    Chat: ChatGroup;
    Conversation: ConversationGroup;
    Dialog: DialogGroup;
    Dnd: DndGroup;
    Emoji: EmojiGroup;
    File: FileGroup;
    Reaction: ReactionGroup;
    Search: SearchGroup;
    Team: TeamGroup;
    UserGroup: UserGroupGroup;
    Reply: ReplyGroup;
    constructor(connection: string, options?: ConnectionOptions);
    /**
     * Performs fetch call using managed connection.
     */
    fetch<T = any>(url: string, options?: RequestInit): Promise<Response<T>>;
    /**
     * Set global error strategy.
     */
    setGlobalErrorStrategy(errorStrategy?: ErrorStrategyHandlers | AssistedErrorStrategyFunction | null): void;
}
declare class BaseGroup {
    protected connection: string;
    protected options: ConnectionOptions;
    constructor(connection: string, options: ConnectionOptions);
    protected getBuildOptions(options: any): any;
}
declare class AdminGroup extends BaseGroup {
    Users: AdminUsersGroup;
    constructor(connection: string, options: ConnectionOptions);
}
declare class AdminUsersGroup extends BaseGroup {
    /**
     * Set an existing guest user, admin user, or owner to be a regular user.
     * Documentation: https://api.slack.com/methods/admin.users.setRegular
     * @param options Request options.
     */
    setRegular<T = Admin.Users.SetRegular.Response.OK>(options: Admin.Users.SetRegular.Options): Promise<Admin.Users.SetRegular.Response.OK>;
    /**
     * Set an existing guest, regular user, or admin user to be a workspace owner.
     * Documentation: https://api.slack.com/methods/admin.users.setOwner
     * @param options Request options.
     */
    setOwner<T = Admin.Users.SetOwner.Response.OK>(options: Admin.Users.SetOwner.Options): Promise<Admin.Users.SetOwner.Response.OK>;
    /**
     * Set an expiration for a guest user
     * Documentation: https://api.slack.com/methods/admin.users.setExpiration
     * @param options Request options.
     */
    setExpiration<T = Admin.Users.SetExpiration.Response.OK>(options: Admin.Users.SetExpiration.Options): Promise<Admin.Users.SetExpiration.Response.OK>;
    /**
     * Set an existing guest, regular user, or owner to be an admin user.
     * Documentation: https://api.slack.com/methods/admin.users.setAdmin
     * @param options Request options.
     */
    setAdmin<T = Admin.Users.SetAdmin.Response.OK>(options: Admin.Users.SetAdmin.Options): Promise<Admin.Users.SetAdmin.Response.OK>;
    /**
     * Remove a user from a workspace.
     * Documentation: https://api.slack.com/methods/admin.users.remove
     * @param options Request options.
     */
    removeUser<T = Admin.Users.RemoveUser.Response.OK>(options: Admin.Users.RemoveUser.Options): Promise<Admin.Users.RemoveUser.Response.OK>;
    /**
     * List users on a workspace
     * Documentation: https://api.slack.com/methods/admin.users.list
     * @param options Request options.
     */
    getUsers<T = Admin.Users.GetUsers.Response.OK>(options: Admin.Users.GetUsers.Options): Promise<Admin.Users.GetUsers.Response.OK>;
    /**
     * Invite a user to a workspace.
     * Documentation: https://api.slack.com/methods/admin.users.invite
     * @param options Request options.
     */
    inviteUser<T = Admin.Users.InviteUser.Response.OK>(options: Admin.Users.InviteUser.Options): Promise<Admin.Users.InviteUser.Response.OK>;
    /**
     * Add an Enterprise user to a workspace.
     * Documentation: https://api.slack.com/methods/admin.users.assign
     * @param options Request options.
     */
    assignUser<T = Admin.Users.AssignUser.Response.OK>(options: Admin.Users.AssignUser.Options): Promise<Admin.Users.AssignUser.Response.OK>;
}
declare class ViewGroup extends BaseGroup {
    /**
     * Update an existing view.
     * Documentation: https://api.slack.com/methods/views.update
     * @param options Request options.
     */
    updateView<T = View.UpdateView.Response.OK>(options: View.UpdateView.Options): Promise<View.UpdateView.Response.OK>;
    /**
     * Push a view onto the stack of a root view.
     * Documentation: https://api.slack.com/methods/views.push
     * @param options Request options.
     */
    pushView<T = View.PushView.Response.OK>(options: View.PushView.Options): Promise<View.PushView.Response.OK>;
    /**
     * Publish a static view for a User.
     * Documentation: https://api.slack.com/methods/views.publish
     * @param options Request options.
     */
    publishView<T = View.PublishView.Response.OK>(options: View.PublishView.Options): Promise<View.PublishView.Response.OK>;
    /**
     * Open a view for a user.
     * Documentation: https://api.slack.com/methods/views.open
     * @param options Request options.
     */
    openView<T = View.OpenView.Response.OK>(options: View.OpenView.Options): Promise<View.OpenView.Response.OK>;
}
declare class UserGroup extends BaseGroup {
    Profile: UserProfileGroup;
    constructor(connection: string, options: ConnectionOptions);
    /**
     * Find a user with an email address.
     * Documentation: https://api.slack.com/methods/users.lookupByEmail
     * @param options Request options.
     */
    getUserByEmail<T = User.GetUserByEmail.Response.OK>(options: User.GetUserByEmail.Options): Promise<User.GetUserByEmail.Response.OK>;
    /**
     * Lists all users in a Slack team.
     * Documentation: https://api.slack.com/methods/users.list
     * @param options Request options.
     */
    getUsers<T = User.GetUsers.Response.OK>(options?: User.GetUsers.Options): Promise<User.GetUsers.Response.OK>;
    /**
     * Gets information about a user.
     * Documentation: https://api.slack.com/methods/users.info
     * @param options Request options.
     */
    getInfo<T = User.GetInfo.Response.OK>(options: User.GetInfo.Options): Promise<User.GetInfo.Response.OK>;
    /**
     * Get a user's identity.
     * Documentation: https://api.slack.com/methods/users.identity
     * @param options Request options.
     */
    getIdentity<T = User.GetIdentity.Response.OK>(options?: User.GetIdentity.Options): Promise<any>;
    /**
     * List conversations the calling user may access.
     * Documentation: https://api.slack.com/methods/users.conversations
     * @param options Request options.
     */
    getConversations<T = User.GetConversations.Response.OK>(options?: User.GetConversations.Options): Promise<User.GetConversations.Response.OK>;
    /**
     * Gets user presence information.
     * Documentation: https://api.slack.com/methods/users.getPresence
     * @param options Request options.
     */
    getPresence<T = User.GetPresence.Response.OK>(options?: User.GetPresence.Options): Promise<User.GetPresence.Response.OK>;
    /**
     * Manually sets user presence.
     * Documentation: https://api.slack.com/methods/users.setPresence
     * @param options Request options.
     */
    setPresence<T = User.SetPresence.Response.OK>(options: User.SetPresence.Options): Promise<User.SetPresence.Response.OK>;
}
declare class UserProfileGroup extends BaseGroup {
    /**
     * Set the profile information for a user.
     * Documentation: https://api.slack.com/methods/users.profile.set
     * @param options Request options.
     */
    setProfile<T = User.Profile.SetProfile.Response.OK>(options: User.Profile.SetProfile.Options): Promise<User.Profile.SetProfile.Response.OK>;
    /**
     * Retrieves a user's profile information.
     * Documentation: https://api.slack.com/methods/users.profile.get
     * @param options Request options.
     */
    getProfile<T = User.Profile.GetProfile.Response.OK>(options?: User.Profile.GetProfile.Options): Promise<User.Profile.GetProfile.Response.OK>;
}
declare class RemindersGroup extends BaseGroup {
    /**
     * Lists all reminders created by or for a given user.
     * Documentation: https://api.slack.com/methods/reminders.list
     * @param options Request options.
     */
    getReminders<T = Reminders.GetReminders.Response.OK>(options?: Reminders.GetReminders.Options): Promise<Reminders.GetReminders.Response.OK>;
    /**
     * Gets information about a reminder.
     * Documentation: https://api.slack.com/methods/reminders.info
     * @param options Request options.
     */
    getInfo<T = Reminders.GetInfo.Response.OK>(options: Reminders.GetInfo.Options): Promise<Reminders.GetInfo.Response.OK>;
    /**
     * Deletes a reminder.
     * Documentation: https://api.slack.com/methods/reminders.delete
     * @param options Request options.
     */
    deleteReminder<T = Reminders.DeleteReminder.Response.OK>(options: Reminders.DeleteReminder.Options): Promise<Reminders.DeleteReminder.Response.OK>;
    /**
     * Marks a reminder as complete.
     * Documentation: https://api.slack.com/methods/reminders.complete
     * @param options Request options.
     */
    completeReminder<T = Reminders.CompleteReminder.Response.OK>(options: Reminders.CompleteReminder.Options): Promise<Reminders.CompleteReminder.Response.OK>;
    /**
     * Creates a reminder.
     * Documentation: https://api.slack.com/methods/reminders.add
     * @param options Request options.
     */
    addReminder<T = Reminders.AddReminder.Response.OK>(options: Reminders.AddReminder.Options): Promise<Reminders.AddReminder.Response.OK>;
}
declare class PinsGroup extends BaseGroup {
    /**
     * Un-pins an item from a channel.
     * Documentation: https://api.slack.com/methods/pins.remove
     * @param options Request options.
     */
    removePin<T = Pins.RemovePin.Response.OK>(options: Pins.RemovePin.Options): Promise<Pins.RemovePin.Response.OK>;
    /**
     * Lists items pinned to a channel.
     * Documentation: https://api.slack.com/methods/pins.list
     * @param options Request options.
     */
    getPins<T = Pins.GetPins.Response.OK>(options: Pins.GetPins.Options): Promise<any>;
    /**
     * Pins an item to a channel.
     * Documentation: https://api.slack.com/methods/pins.add
     * @param options Request options.
     */
    addPin<T = Pins.AddPin.Response.OK>(options: Pins.AddPin.Options): Promise<Pins.AddPin.Response.OK>;
}
declare class BotGroup extends BaseGroup {
    /**
     * Gets information about a bot user.
     * Documentation: https://api.slack.com/methods/bots.info
     * @param options Request options.
     */
    getInfo<T = Bot.GetInfo.Response.OK>(options?: Bot.GetInfo.Options): Promise<Bot.GetInfo.Response.OK>;
}
declare class ChatGroup extends BaseGroup {
    ScheduledMessage: ChatScheduledMessageGroup;
    constructor(connection: string, options: ConnectionOptions);
    /**
     * Deletes a message.
     * Documentation: https://api.slack.com/methods/chat.delete
     * @param options Request options.
     */
    deleteMessage<T = Chat.DeleteMessage.Response.OK>(options: Chat.DeleteMessage.Options): Promise<Chat.DeleteMessage.Response.OK>;
    /**
     * Deletes a pending scheduled message from the queue.
     * Documentation: https://api.slack.com/methods/chat.deleteScheduledMessage
     * @param options Request options.
     */
    deleteScheduledMessage<T = Chat.DeleteScheduledMessage.Response.OK>(options: Chat.DeleteScheduledMessage.Options): Promise<Chat.DeleteScheduledMessage.Response.OK>;
    /**
     * Retrieve a permalink URL for a specific extant message
     * Documentation: https://api.slack.com/methods/chat.getPermalink
     * @param options Request options.
     */
    getPermalink<T = Chat.GetPermalink.Response.OK>(options: Chat.GetPermalink.Options): Promise<Chat.GetPermalink.Response.OK>;
    /**
     * Share a me message into a channel.
     * Documentation: https://api.slack.com/methods/chat.meMessage
     * @param options Request options.
     */
    postMeMessage<T = Chat.PostMeMessage.Response.OK>(options: Chat.PostMeMessage.Options): Promise<Chat.PostMeMessage.Response.OK>;
    /**
     * Sends an ephemeral message to a user in a channel.
     * Documentation: https://api.slack.com/methods/chat.postEphemeral
     * @param options Request options.
     */
    postEphemeralMessage<T = Chat.PostEphemeralMessage.Response.OK>(options: Chat.PostEphemeralMessage.Options): Promise<Chat.PostEphemeralMessage.Response.OK>;
    /**
     * Sends a message to a channel.
     * Documentation: https://api.slack.com/methods/chat.postMessage
     * @param options Request options.
     */
    postMessage<T = Chat.PostMessage.Response.OK>(options: Chat.PostMessage.Options): Promise<Chat.PostMessage.Response.OK>;
    /**
     * Schedules a message to be sent to a channel.
     * Documentation: https://api.slack.com/methods/chat.scheduleMessage
     * @param options Request options.
     */
    scheduleMessage<T = Chat.ScheduleMessage.Response.OK>(options: Chat.ScheduleMessage.Options): Promise<Chat.ScheduleMessage.Response.OK>;
    /**
     * Provide custom unfurl behavior for user-posted URLs
     * Documentation: https://api.slack.com/methods/chat.unfurl
     * @param options Request options.
     */
    unfurlMessage<T = Chat.UnfurlMessage.Response.OK>(options: Chat.UnfurlMessage.Options): Promise<Chat.UnfurlMessage.Response.OK>;
    /**
     * Updates a message.
     * Documentation: https://api.slack.com/methods/chat.update
     * @param options Request options.
     */
    updateMessage<T = Chat.UpdateMessage.Response.OK>(options: Chat.UpdateMessage.Options): Promise<Chat.UpdateMessage.Response.OK>;
}
declare class ChatScheduledMessageGroup extends BaseGroup {
    /**
     * Returns a list of scheduled messages.
     * Documentation: https://api.slack.com/methods/chat.scheduledMessages.list
     * @param options Request options.
     */
    getScheduledMessages<T = Chat.ScheduledMessage.GetScheduledMessages.Response.OK>(options?: Chat.ScheduledMessage.GetScheduledMessages.Options): Promise<Chat.ScheduledMessage.GetScheduledMessages.Response.OK>;
}
declare class ConversationGroup extends BaseGroup {
    /**
     * Archives a conversation.
     * Documentation: https://api.slack.com/methods/conversations.archive
     * @param options Request options.
     */
    archiveConversation<T = Conversation.ArchiveConversation.Response.OK>(options: Conversation.ArchiveConversation.Options): Promise<Conversation.ArchiveConversation.Response.OK>;
    /**
     * Closes a direct message or multi-person direct message.
     * Documentation: https://api.slack.com/methods/conversations.close
     * @param options Request options.
     */
    closeConversation<T = Conversation.CloseConversation.Response.OK>(options: Conversation.CloseConversation.Options): Promise<Conversation.CloseConversation.Response.OK>;
    /**
     * Initiates a public or private channel-based conversation
     * Documentation: https://api.slack.com/methods/conversations.create
     * @param options Request options.
     */
    createConversation<T = Conversation.CreateConversation.Response.OK>(options: Conversation.CreateConversation.Options): Promise<Conversation.CreateConversation.Response.OK>;
    /**
     * Fetches a conversation's history of messages and events.
     * Documentation: https://api.slack.com/methods/conversations.history
     * @param options Request options.
     */
    getHistory<T = Conversation.GetHistory.Response.OK>(options?: Conversation.GetHistory.Options): Promise<Conversation.GetHistory.Response.OK>;
    /**
     * Retrieve information about a conversation.
     * Documentation: https://api.slack.com/methods/conversations.info
     * @param options Request options.
     */
    getInfo<T = Conversation.GetInfo.Response.OK>(options: Conversation.GetInfo.Options): Promise<Conversation.GetInfo.Response.OK>;
    /**
     * Invites users to a channel.
     * Documentation: https://api.slack.com/methods/conversations.invite
     * @param options Request options.
     */
    inviteUser<T = Conversation.InviteUser.Response.OK>(options: Conversation.InviteUser.Options): Promise<Conversation.InviteUser.Response.OK>;
    /**
     * Joins an existing conversation.
     * Documentation: https://api.slack.com/methods/conversations.join
     * @param options Request options.
     */
    joinConversation<T = Conversation.JoinConversation.Response.OK>(options: Conversation.JoinConversation.Options): Promise<Conversation.JoinConversation.Response.OK>;
    /**
     * Removes a user from a conversation.
     * Documentation: https://api.slack.com/methods/conversations.kick
     * @param options Request options.
     */
    kickUser<T = Conversation.KickUser.Response.OK>(options: Conversation.KickUser.Options): Promise<Conversation.KickUser.Response.OK>;
    /**
     * Leaves a conversation.
     * Documentation: https://api.slack.com/methods/conversations.leave
     * @param options Request options.
     */
    leaveConversation<T = Conversation.LeaveConversation.Response.OK>(options: Conversation.LeaveConversation.Options): Promise<Conversation.LeaveConversation.Response.OK>;
    /**
     * Lists all channels in a Slack team.
     * Documentation: https://api.slack.com/methods/conversations.list
     * @param options Request options.
     */
    getConversations<T = Conversation.GetConversations.Response.OK>(options?: Conversation.GetConversations.Options): Promise<Conversation.GetConversations.Response.OK>;
    /**
     * Retrieve members of a conversation.
     * Documentation: https://api.slack.com/methods/conversations.members
     * @param options Request options.
     */
    getMembers<T = Conversation.GetMembers.Response.OK>(options: Conversation.GetMembers.Options): Promise<Conversation.GetMembers.Response.OK>;
    /**
     * Opens or resumes a direct message or multi-person direct message.
     * Documentation: https://api.slack.com/methods/conversations.open
     * @param options Request options.
     */
    openConversation<T = Conversation.OpenConversation.Response.OK>(options: Conversation.OpenConversation.Options): Promise<Conversation.OpenConversation.Response.OK>;
    /**
     * Renames a conversation.
     * Documentation: https://api.slack.com/methods/conversations.rename
     * @param options Request options.
     */
    renameConversation<T = Conversation.RenameConversation.Response.OK>(options: Conversation.RenameConversation.Options): Promise<Conversation.RenameConversation.Response.OK>;
    /**
     * Retrieve a thread of messages posted to a conversation
     * Documentation: https://api.slack.com/methods/conversations.replies
     * @param options Request options.
     */
    getReplies<T = Conversation.GetReplies.Response.OK>(options?: Conversation.GetReplies.Options): Promise<Conversation.GetReplies.Response.OK>;
    /**
     * Sets the purpose for a conversation.
     * Documentation: https://api.slack.com/methods/conversations.setPurpose
     * @param options Request options.
     */
    setPurpose<T = Conversation.SetPurpose.Response.OK>(options: Conversation.SetPurpose.Options): Promise<Conversation.SetPurpose.Response.OK>;
    /**
     * Sets the topic for a conversation.
     * Documentation: https://api.slack.com/methods/conversations.setTopic
     * @param options Request options.
     */
    setTopic<T = Conversation.SetTopic.Response.OK>(options: Conversation.SetTopic.Options): Promise<Conversation.SetTopic.Response.OK>;
    /**
     * Reverses conversation archival.
     * Documentation: https://api.slack.com/methods/conversations.unarchive
     * @param options Request options.
     */
    unarchiveConversation<T = Conversation.UnarchiveConversation.Response.OK>(options: Conversation.UnarchiveConversation.Options): Promise<Conversation.UnarchiveConversation.Response.OK>;
}
declare class DialogGroup extends BaseGroup {
    /**
     * Open a dialog with a user
     * Documentation: https://api.slack.com/methods/dialog.open
     * @param options Request options.
     */
    openDialog<T = Dialog.OpenDialog.Response.OK>(options: Dialog.OpenDialog.Options): Promise<Dialog.OpenDialog.Response.OK>;
}
declare class DndGroup extends BaseGroup {
    /**
     * Ends the current user's Do Not Disturb session immediately.
     * Documentation: https://api.slack.com/methods/dnd.endDnd
     * @param options Request options.
     */
    endDnd<T = Dnd.EndDnd.Response.OK>(options?: Dnd.EndDnd.Options): Promise<Dnd.EndDnd.Response.OK>;
    /**
     * Ends the current user's snooze mode immediately.
     * Documentation: https://api.slack.com/methods/dnd.endSnooze
     * @param options Request options.
     */
    endSnooze<T = Dnd.EndSnooze.Response.OK>(options?: Dnd.EndSnooze.Options): Promise<Dnd.EndSnooze.Response.OK>;
    /**
     * Retrieves a user's current Do Not Disturb status.
     * Documentation: https://api.slack.com/methods/dnd.info
     * @param options Request options.
     */
    getInfo<T = Dnd.GetInfo.Response.OK>(options?: Dnd.GetInfo.Options): Promise<Dnd.GetInfo.Response.OK>;
    /**
     * Turns on Do Not Disturb mode for the current user, or changes its duration.
     * Documentation: https://api.slack.com/methods/dnd.setSnooze
     * @param options Request options.
     */
    setSnooze<T = Dnd.SetSnooze.Response.OK>(options: Dnd.SetSnooze.Options): Promise<Dnd.SetSnooze.Response.OK>;
    /**
     * Retrieves the Do Not Disturb status for up to 50 users on a team.
     * Documentation: https://api.slack.com/methods/dnd.teamInfo
     * @param options Request options.
     */
    getTeamInfo<T = Dnd.GetTeamInfo.Response.OK>(options: Dnd.GetTeamInfo.Options): Promise<Dnd.GetTeamInfo.Response.OK>;
}
declare class EmojiGroup extends BaseGroup {
    /**
     * Lists custom emoji for a team.
     * Documentation: https://api.slack.com/methods/emoji.list
     * @param options Request options.
     */
    getEmojis<T = Emoji.GetEmojis.Response.OK>(options?: Emoji.GetEmojis.Options): Promise<Emoji.GetEmojis.Response.OK>;
}
declare class FileGroup extends BaseGroup {
    Comment: FileCommentGroup;
    PublicUrl: FilePublicUrlGroup;
    Remote: FileRemoteGroup;
    constructor(connection: string, options: ConnectionOptions);
    /**
     * Deletes a file.
     * Documentation: https://api.slack.com/methods/files.delete
     * @param options Request options.
     */
    deleteFile<T = File.DeleteFile.Response.OK>(options: File.DeleteFile.Options): Promise<File.DeleteFile.Response.OK>;
    /**
     * Gets information about a file.
     * Documentation: https://api.slack.com/methods/files.info
     * @param options Request options.
     */
    getInfo<T = File.GetInfo.Response.OK>(options?: File.GetInfo.Options): Promise<File.GetInfo.Response.OK>;
    /**
     * List for a team, in a channel, or from a user with applied filters.
     * Documentation: https://api.slack.com/methods/files.list
     * @param options Request options.
     */
    getFiles<T = File.GetFiles.Response.OK>(options?: File.GetFiles.Options): Promise<File.GetFiles.Response.OK>;
    /**
     * Uploads or creates a file.
     * Documentation: https://api.slack.com/methods/files.upload
     * @param options Request options.
     */
    uploadFile<T = File.UploadFile.Response.OK>(options: File.UploadFile.Options): Promise<File.UploadFile.Response.OK>;
}
declare class FileCommentGroup extends BaseGroup {
    /**
     * Deletes an existing comment on a file.
     * Documentation: https://api.slack.com/methods/files.comments.delete
     * @param options Request options.
     */
    deleteComment<T = File.Comment.DeleteComment.Response.OK>(options: File.Comment.DeleteComment.Options): Promise<File.Comment.DeleteComment.Response.OK>;
}
declare class FilePublicUrlGroup extends BaseGroup {
    /**
     * Revokes public/external sharing access for a file
     * Documentation: https://api.slack.com/methods/files.revokePublicURL
     * @param options Request options.
     */
    revokePublicUrl<T = File.PublicUrl.RevokePublicUrl.Response.OK>(options: File.PublicUrl.RevokePublicUrl.Options): Promise<File.PublicUrl.RevokePublicUrl.Response.OK>;
    /**
     * Enables a file for public/external sharing.
     * Documentation: https://api.slack.com/methods/files.sharedPublicURL
     * @param options Request options.
     */
    createPublicUrl<T = File.PublicUrl.CreatePublicUrl.Response.OK>(options: File.PublicUrl.CreatePublicUrl.Options): Promise<File.PublicUrl.CreatePublicUrl.Response.OK>;
}
declare class FileRemoteGroup extends BaseGroup {
    /**
     * Adds a file from a remote service
     * Documentation: https://api.slack.com/methods/files.remote.add
     * @param options Request options.
     */
    addFile<T = File.Remote.AddFile.Response.OK>(options: File.Remote.AddFile.Options): Promise<File.Remote.AddFile.Response.OK>;
    /**
     * Retrieve information about a remote file added to Slack
     * Documentation: https://api.slack.com/methods/files.remote.info
     * @param options Request options.
     */
    getInfo<T = File.Remote.GetInfo.Response.OK>(options?: File.Remote.GetInfo.Options): Promise<File.Remote.GetInfo.Response.OK>;
    /**
     * Retrieve information about a remote file added to Slack
     * Documentation: https://api.slack.com/methods/files.remote.list
     * @param options Request options.
     */
    getFiles<T = File.Remote.GetFiles.Response.OK>(options?: File.Remote.GetFiles.Options): Promise<File.Remote.GetFiles.Response.OK>;
    /**
     * Remove a remote file.
     * Documentation: https://api.slack.com/methods/files.remote.remove
     * @param options Request options.
     */
    removeFile<T = File.Remote.RemoveFile.Response.OK>(options?: File.Remote.RemoveFile.Options): Promise<File.Remote.RemoveFile.Response.OK>;
    /**
     * Share a remote file into a channel.
     * Documentation: https://api.slack.com/methods/files.remote.share
     * @param options Request options.
     */
    shareFile<T = File.Remote.ShareFile.Response.OK>(options?: File.Remote.ShareFile.Options): Promise<File.Remote.ShareFile.Response.OK>;
    /**
     * Updates an existing remote file.
     * Documentation: https://api.slack.com/methods/files.remote.update
     * @param options Request options.
     */
    updateFile<T = File.Remote.UpdateFile.Response.OK>(options?: File.Remote.UpdateFile.Options): Promise<File.Remote.UpdateFile.Response.OK>;
}
declare class ReactionGroup extends BaseGroup {
    /**
     * Adds a reaction to an item.
     * Documentation: https://api.slack.com/methods/reactions.add
     * @param options Request options.
     */
    addReaction<T = Reaction.AddReaction.Response.OK>(options: Reaction.AddReaction.Options): Promise<Reaction.AddReaction.Response.OK>;
    /**
     * Gets reactions for an item.
     * Documentation: https://api.slack.com/methods/reactions.get
     * @param options Request options.
     */
    getReaction<T = Reaction.GetReaction.Response.OK>(options?: Reaction.GetReaction.Options): Promise<Reaction.GetReaction.Response.OK>;
    /**
     * Lists reactions made by a user.
     * Documentation: https://api.slack.com/methods/reactions.list
     * @param options Request options.
     */
    getReactions<T = Reaction.GetReactions.Response.OK>(options?: Reaction.GetReactions.Options): Promise<Reaction.GetReactions.Response.OK>;
    /**
     * Removes a reaction from an item.
     * Documentation: https://api.slack.com/methods/reactions.remove
     * @param options Request options.
     */
    removeReaction<T = Reaction.RemoveReaction.Response.OK>(options: Reaction.RemoveReaction.Options): Promise<Reaction.RemoveReaction.Response.OK>;
}
declare class SearchGroup extends BaseGroup {
    /**
     * Searches for messages matching a query.
     * Documentation: https://api.slack.com/methods/search.messages
     * @param options Request options.
     */
    searchMessages<T = Search.SearchMessages.Response.OK>(options: Search.SearchMessages.Options): Promise<Search.SearchMessages.Response.OK>;
}
declare class TeamGroup extends BaseGroup {
    Profile: TeamProfileGroup;
    constructor(connection: string, options: ConnectionOptions);
    /**
     * Gets the access logs for the current team.
     * Documentation: https://api.slack.com/methods/team.accessLogs
     * @param options Request options.
     */
    getAccessLogs<T = Team.GetAccessLogs.Response.OK>(options?: Team.GetAccessLogs.Options): Promise<Team.GetAccessLogs.Response.OK>;
    /**
     * Gets billable users information for the current team.
     * Documentation: https://api.slack.com/methods/team.billableInfo
     * @param options Request options.
     */
    getBillableInfo<T = Team.GetBillableInfo.Response.OK>(options?: Team.GetBillableInfo.Options): Promise<Team.GetBillableInfo.Response.OK>;
    /**
     * Gets information about the current team.
     * Documentation: https://api.slack.com/methods/team.info
     * @param options Request options.
     */
    getInfo<T = Team.GetInfo.Response.OK>(options?: Team.GetInfo.Options): Promise<Team.GetInfo.Response.OK>;
    /**
     * Gets the integration logs for the current team.
     * Documentation: https://api.slack.com/methods/team.integrationLogs
     * @param options Request options.
     */
    getIntegrationLogs<T = Team.GetIntegrationLogs.Response.OK>(options?: Team.GetIntegrationLogs.Options): Promise<Team.GetIntegrationLogs.Response.OK>;
}
declare class TeamProfileGroup extends BaseGroup {
    /**
     * Retrieve a team's profile.
     * Documentation: https://api.slack.com/methods/team.profile.get
     * @param options Request options.
     */
    getProfile<T = Team.Profile.GetProfile.Response.OK>(options?: Team.Profile.GetProfile.Options): Promise<Team.Profile.GetProfile.Response.OK>;
}
declare class UserGroupGroup extends BaseGroup {
    User: UserGroupUserGroup;
    constructor(connection: string, options: ConnectionOptions);
    /**
     * Create a User Group
     * Documentation: https://api.slack.com/methods/usergroups.create
     * @param options Request options.
     */
    createUserGroup<T = UserGroup.CreateUserGroup.Response.OK>(options: UserGroup.CreateUserGroup.Options): Promise<UserGroup.CreateUserGroup.Response.OK>;
    /**
     * Disable an existing User Group
     * Documentation: https://api.slack.com/methods/usergroups.disable
     * @param options Request options.
     */
    disableUserGroup<T = UserGroup.DisableUserGroup.Response.OK>(options: UserGroup.DisableUserGroup.Options): Promise<UserGroup.DisableUserGroup.Response.OK>;
    /**
     * Enable a User Group
     * Documentation: https://api.slack.com/methods/usergroups.enable
     * @param options Request options.
     */
    enableUserGroup<T = UserGroup.EnableUserGroup.Response.OK>(options: UserGroup.EnableUserGroup.Options): Promise<UserGroup.EnableUserGroup.Response.OK>;
    /**
     * List all User Groups for a team
     * Documentation: https://api.slack.com/methods/usergroups.list
     * @param options Request options.
     */
    getUserGroups<T = UserGroup.GetUserGroups.Response.OK>(options?: UserGroup.GetUserGroups.Options): Promise<UserGroup.GetUserGroups.Response.OK>;
    /**
     * Update an existing User Group
     * Documentation: https://api.slack.com/methods/usergroups.update
     * @param options Request options.
     */
    updateUserGroup<T = UserGroup.UpdateUserGroup.Response.OK>(options: UserGroup.UpdateUserGroup.Options): Promise<UserGroup.UpdateUserGroup.Response.OK>;
}
declare class UserGroupUserGroup extends BaseGroup {
    /**
     * List all users in a User Group
     * Documentation: https://api.slack.com/methods/usergroups.users.list
     * @param options Request options.
     */
    getUsers<T = UserGroup.User.GetUsers.Response.OK>(options: UserGroup.User.GetUsers.Options): Promise<UserGroup.User.GetUsers.Response.OK>;
    /**
     * Update the list of users for a User Group
     * Documentation: https://api.slack.com/methods/usergroups.users.update
     * @param options Request options.
     */
    updateUsers<T = UserGroup.User.UpdateUsers.Response.OK>(options: UserGroup.User.UpdateUsers.Options): Promise<UserGroup.User.UpdateUsers.Response.OK>;
}
declare class ReplyGroup extends BaseGroup {
    /**
     * Send message back to Slack using the response_url in the event payload.
     * Documentation: https://api.slack.com/interactivity/handling#message_responses
     * @param options Request options.
     */
    postMessage<T = Reply.PostMessage.Response.OK>(options: Reply.PostMessage.Options): Promise<Reply.PostMessage.Response.OK>;
}
declare class AllGroup extends BaseGroup {
    constructor(connection: string, options: ConnectionOptions);
    /**
     * Set an existing guest user, admin user, or owner to be a regular user.
     * Recommended usage: Admin.Users.setRegular
     * Documentation: https://api.slack.com/methods/admin.users.setRegular
     * @param options Request options.
     */
    adminSetRegularUser<T = Admin.Users.SetRegular.Response.OK>(options: Admin.Users.SetRegular.Options): Promise<Admin.Users.SetRegular.Response.OK>;
    /**
     * Set an existing guest, regular user, or admin user to be a workspace owner.
     * Recommended usage: Admin.Users.setOwner
     * Documentation: https://api.slack.com/methods/admin.users.setOwner
     * @param options Request options.
     */
    adminSetOwnerUser<T = Admin.Users.SetOwner.Response.OK>(options: Admin.Users.SetOwner.Options): Promise<Admin.Users.SetOwner.Response.OK>;
    /**
     * Set an expiration for a guest user
     * Recommended usage: Admin.Users.setExpiration
     * Documentation: https://api.slack.com/methods/admin.users.setExpiration
     * @param options Request options.
     */
    adminSetUserExpiration<T = Admin.Users.SetExpiration.Response.OK>(options: Admin.Users.SetExpiration.Options): Promise<Admin.Users.SetExpiration.Response.OK>;
    /**
     * Set an existing guest, regular user, or owner to be an admin user.
     * Recommended usage: Admin.Users.setAdmin
     * Documentation: https://api.slack.com/methods/admin.users.setAdmin
     * @param options Request options.
     */
    adminSetAdminUser<T = Admin.Users.SetAdmin.Response.OK>(options: Admin.Users.SetAdmin.Options): Promise<Admin.Users.SetAdmin.Response.OK>;
    /**
     * Remove a user from a workspace.
     * Recommended usage: Admin.Users.removeUser
     * Documentation: https://api.slack.com/methods/admin.users.remove
     * @param options Request options.
     */
    adminRemoveUser<T = Admin.Users.RemoveUser.Response.OK>(options: Admin.Users.RemoveUser.Options): Promise<Admin.Users.RemoveUser.Response.OK>;
    /**
     * List users on a workspace
     * Recommended usage: Admin.Users.getUsers
     * Documentation: https://api.slack.com/methods/admin.users.list
     * @param options Request options.
     */
    adminGetUsers<T = Admin.Users.GetUsers.Response.OK>(options: Admin.Users.GetUsers.Options): Promise<Admin.Users.GetUsers.Response.OK>;
    /**
     * Invite a user to a workspace.
     * Recommended usage: Admin.Users.inviteUser
     * Documentation: https://api.slack.com/methods/admin.users.invite
     * @param options Request options.
     */
    adminInviteUser<T = Admin.Users.InviteUser.Response.OK>(options: Admin.Users.InviteUser.Options): Promise<Admin.Users.InviteUser.Response.OK>;
    /**
     * Add an Enterprise user to a workspace.
     * Recommended usage: Admin.Users.assignUser
     * Documentation: https://api.slack.com/methods/admin.users.assign
     * @param options Request options.
     */
    adminAssignUser<T = Admin.Users.AssignUser.Response.OK>(options: Admin.Users.AssignUser.Options): Promise<Admin.Users.AssignUser.Response.OK>;
    /**
     * Update an existing view.
     * Recommended usage: View.updateView
     * Documentation: https://api.slack.com/methods/views.update
     * @param options Request options.
     */
    updateView<T = View.UpdateView.Response.OK>(options: View.UpdateView.Options): Promise<View.UpdateView.Response.OK>;
    /**
     * Push a view onto the stack of a root view.
     * Recommended usage: View.pushView
     * Documentation: https://api.slack.com/methods/views.push
     * @param options Request options.
     */
    pushView<T = View.PushView.Response.OK>(options: View.PushView.Options): Promise<View.PushView.Response.OK>;
    /**
     * Publish a static view for a User.
     * Recommended usage: View.publishView
     * Documentation: https://api.slack.com/methods/views.publish
     * @param options Request options.
     */
    publishView<T = View.PublishView.Response.OK>(options: View.PublishView.Options): Promise<View.PublishView.Response.OK>;
    /**
     * Open a view for a user.
     * Recommended usage: View.openView
     * Documentation: https://api.slack.com/methods/views.open
     * @param options Request options.
     */
    openView<T = View.OpenView.Response.OK>(options: View.OpenView.Options): Promise<View.OpenView.Response.OK>;
    /**
     * Find a user with an email address.
     * Recommended usage: User.getUserByEmail
     * Documentation: https://api.slack.com/methods/users.lookupByEmail
     * @param options Request options.
     */
    getUserByEmail<T = User.GetUserByEmail.Response.OK>(options: User.GetUserByEmail.Options): Promise<User.GetUserByEmail.Response.OK>;
    /**
     * Lists all users in a Slack team.
     * Recommended usage: User.getUsers
     * Documentation: https://api.slack.com/methods/users.list
     * @param options Request options.
     */
    getUsers<T = User.GetUsers.Response.OK>(options?: User.GetUsers.Options): Promise<User.GetUsers.Response.OK>;
    /**
     * Gets information about a user.
     * Recommended usage: User.getInfo
     * Documentation: https://api.slack.com/methods/users.info
     * @param options Request options.
     */
    getUserInfo<T = User.GetInfo.Response.OK>(options: User.GetInfo.Options): Promise<User.GetInfo.Response.OK>;
    /**
     * Get a user's identity.
     * Recommended usage: User.getIdentity
     * Documentation: https://api.slack.com/methods/users.identity
     * @param options Request options.
     */
    getUserIdentity<T = User.GetIdentity.Response.OK>(options?: User.GetIdentity.Options): Promise<any>;
    /**
     * List conversations the calling user may access.
     * Recommended usage: User.getConversations
     * Documentation: https://api.slack.com/methods/users.conversations
     * @param options Request options.
     */
    getUserConversations<T = User.GetConversations.Response.OK>(options?: User.GetConversations.Options): Promise<User.GetConversations.Response.OK>;
    /**
     * Gets user presence information.
     * Recommended usage: User.getPresence
     * Documentation: https://api.slack.com/methods/users.getPresence
     * @param options Request options.
     */
    getUserPresence<T = User.GetPresence.Response.OK>(options?: User.GetPresence.Options): Promise<User.GetPresence.Response.OK>;
    /**
     * Manually sets user presence.
     * Recommended usage: User.setPresence
     * Documentation: https://api.slack.com/methods/users.setPresence
     * @param options Request options.
     */
    setUserPresence<T = User.SetPresence.Response.OK>(options: User.SetPresence.Options): Promise<User.SetPresence.Response.OK>;
    /**
     * Set the profile information for a user.
     * Recommended usage: User.Profile.setProfile
     * Documentation: https://api.slack.com/methods/users.profile.set
     * @param options Request options.
     */
    setUserProfile<T = User.Profile.SetProfile.Response.OK>(options: User.Profile.SetProfile.Options): Promise<User.Profile.SetProfile.Response.OK>;
    /**
     * Retrieves a user's profile information.
     * Recommended usage: User.Profile.getProfile
     * Documentation: https://api.slack.com/methods/users.profile.get
     * @param options Request options.
     */
    getUserProfile<T = User.Profile.GetProfile.Response.OK>(options?: User.Profile.GetProfile.Options): Promise<User.Profile.GetProfile.Response.OK>;
    /**
     * Lists all reminders created by or for a given user.
     * Recommended usage: Reminders.getReminders
     * Documentation: https://api.slack.com/methods/reminders.list
     * @param options Request options.
     */
    getReminders<T = Reminders.GetReminders.Response.OK>(options?: Reminders.GetReminders.Options): Promise<Reminders.GetReminders.Response.OK>;
    /**
     * Gets information about a reminder.
     * Recommended usage: Reminders.getInfo
     * Documentation: https://api.slack.com/methods/reminders.info
     * @param options Request options.
     */
    getReminderInfo<T = Reminders.GetInfo.Response.OK>(options: Reminders.GetInfo.Options): Promise<Reminders.GetInfo.Response.OK>;
    /**
     * Deletes a reminder.
     * Recommended usage: Reminders.deleteReminder
     * Documentation: https://api.slack.com/methods/reminders.delete
     * @param options Request options.
     */
    deleteReminder<T = Reminders.DeleteReminder.Response.OK>(options: Reminders.DeleteReminder.Options): Promise<Reminders.DeleteReminder.Response.OK>;
    /**
     * Marks a reminder as complete.
     * Recommended usage: Reminders.completeReminder
     * Documentation: https://api.slack.com/methods/reminders.complete
     * @param options Request options.
     */
    completeReminder<T = Reminders.CompleteReminder.Response.OK>(options: Reminders.CompleteReminder.Options): Promise<Reminders.CompleteReminder.Response.OK>;
    /**
     * Creates a reminder.
     * Recommended usage: Reminders.addReminder
     * Documentation: https://api.slack.com/methods/reminders.add
     * @param options Request options.
     */
    addReminder<T = Reminders.AddReminder.Response.OK>(options: Reminders.AddReminder.Options): Promise<Reminders.AddReminder.Response.OK>;
    /**
     * Un-pins an item from a channel.
     * Recommended usage: Pins.removePin
     * Documentation: https://api.slack.com/methods/pins.remove
     * @param options Request options.
     */
    removePin<T = Pins.RemovePin.Response.OK>(options: Pins.RemovePin.Options): Promise<Pins.RemovePin.Response.OK>;
    /**
     * Lists items pinned to a channel.
     * Recommended usage: Pins.getPins
     * Documentation: https://api.slack.com/methods/pins.list
     * @param options Request options.
     */
    getPins<T = Pins.GetPins.Response.OK>(options: Pins.GetPins.Options): Promise<any>;
    /**
     * Pins an item to a channel.
     * Recommended usage: Pins.addPin
     * Documentation: https://api.slack.com/methods/pins.add
     * @param options Request options.
     */
    addPin<T = Pins.AddPin.Response.OK>(options: Pins.AddPin.Options): Promise<Pins.AddPin.Response.OK>;
    /**
     * Gets information about a bot user.
     * Recommended usage: Bot.getInfo
     * Documentation: https://api.slack.com/methods/bots.info
     * @param options Request options.
     */
    getBotInfo<T = Bot.GetInfo.Response.OK>(options?: Bot.GetInfo.Options): Promise<Bot.GetInfo.Response.OK>;
    /**
     * Deletes a message.
     * Recommended usage: Chat.deleteMessage
     * Documentation: https://api.slack.com/methods/chat.delete
     * @param options Request options.
     */
    deleteChatMessage<T = Chat.DeleteMessage.Response.OK>(options: Chat.DeleteMessage.Options): Promise<Chat.DeleteMessage.Response.OK>;
    /**
     * Deletes a pending scheduled message from the queue.
     * Recommended usage: Chat.deleteScheduledMessage
     * Documentation: https://api.slack.com/methods/chat.deleteScheduledMessage
     * @param options Request options.
     */
    deleteChatScheduledMessage<T = Chat.DeleteScheduledMessage.Response.OK>(options: Chat.DeleteScheduledMessage.Options): Promise<Chat.DeleteScheduledMessage.Response.OK>;
    /**
     * Retrieve a permalink URL for a specific extant message
     * Recommended usage: Chat.getPermalink
     * Documentation: https://api.slack.com/methods/chat.getPermalink
     * @param options Request options.
     */
    getChatPermalink<T = Chat.GetPermalink.Response.OK>(options: Chat.GetPermalink.Options): Promise<Chat.GetPermalink.Response.OK>;
    /**
     * Share a me message into a channel.
     * Recommended usage: Chat.postMeMessage
     * Documentation: https://api.slack.com/methods/chat.meMessage
     * @param options Request options.
     */
    postChatMeMessage<T = Chat.PostMeMessage.Response.OK>(options: Chat.PostMeMessage.Options): Promise<Chat.PostMeMessage.Response.OK>;
    /**
     * Sends an ephemeral message to a user in a channel.
     * Recommended usage: Chat.postEphemeralMessage
     * Documentation: https://api.slack.com/methods/chat.postEphemeral
     * @param options Request options.
     */
    postChatEphemeralMessage<T = Chat.PostEphemeralMessage.Response.OK>(options: Chat.PostEphemeralMessage.Options): Promise<Chat.PostEphemeralMessage.Response.OK>;
    /**
     * Sends a message to a channel.
     * Recommended usage: Chat.postMessage
     * Documentation: https://api.slack.com/methods/chat.postMessage
     * @param options Request options.
     */
    postChatMessage<T = Chat.PostMessage.Response.OK>(options: Chat.PostMessage.Options): Promise<Chat.PostMessage.Response.OK>;
    /**
     * Schedules a message to be sent to a channel.
     * Recommended usage: Chat.scheduleMessage
     * Documentation: https://api.slack.com/methods/chat.scheduleMessage
     * @param options Request options.
     */
    scheduleChatMessage<T = Chat.ScheduleMessage.Response.OK>(options: Chat.ScheduleMessage.Options): Promise<Chat.ScheduleMessage.Response.OK>;
    /**
     * Provide custom unfurl behavior for user-posted URLs
     * Recommended usage: Chat.unfurlMessage
     * Documentation: https://api.slack.com/methods/chat.unfurl
     * @param options Request options.
     */
    unfurlChatMessage<T = Chat.UnfurlMessage.Response.OK>(options: Chat.UnfurlMessage.Options): Promise<Chat.UnfurlMessage.Response.OK>;
    /**
     * Updates a message.
     * Recommended usage: Chat.updateMessage
     * Documentation: https://api.slack.com/methods/chat.update
     * @param options Request options.
     */
    updateChatMessage<T = Chat.UpdateMessage.Response.OK>(options: Chat.UpdateMessage.Options): Promise<Chat.UpdateMessage.Response.OK>;
    /**
     * Returns a list of scheduled messages.
     * Recommended usage: Chat.ScheduledMessage.getScheduledMessages
     * Documentation: https://api.slack.com/methods/chat.scheduledMessages.list
     * @param options Request options.
     */
    getChatScheduledMessages<T = Chat.ScheduledMessage.GetScheduledMessages.Response.OK>(options?: Chat.ScheduledMessage.GetScheduledMessages.Options): Promise<Chat.ScheduledMessage.GetScheduledMessages.Response.OK>;
    /**
     * Archives a conversation.
     * Recommended usage: Conversation.archiveConversation
     * Documentation: https://api.slack.com/methods/conversations.archive
     * @param options Request options.
     */
    archiveConversation<T = Conversation.ArchiveConversation.Response.OK>(options: Conversation.ArchiveConversation.Options): Promise<Conversation.ArchiveConversation.Response.OK>;
    /**
     * Closes a direct message or multi-person direct message.
     * Recommended usage: Conversation.closeConversation
     * Documentation: https://api.slack.com/methods/conversations.close
     * @param options Request options.
     */
    closeConversation<T = Conversation.CloseConversation.Response.OK>(options: Conversation.CloseConversation.Options): Promise<Conversation.CloseConversation.Response.OK>;
    /**
     * Initiates a public or private channel-based conversation
     * Recommended usage: Conversation.createConversation
     * Documentation: https://api.slack.com/methods/conversations.create
     * @param options Request options.
     */
    createConversation<T = Conversation.CreateConversation.Response.OK>(options: Conversation.CreateConversation.Options): Promise<Conversation.CreateConversation.Response.OK>;
    /**
     * Fetches a conversation's history of messages and events.
     * Recommended usage: Conversation.getHistory
     * Documentation: https://api.slack.com/methods/conversations.history
     * @param options Request options.
     */
    getConversationHistory<T = Conversation.GetHistory.Response.OK>(options?: Conversation.GetHistory.Options): Promise<Conversation.GetHistory.Response.OK>;
    /**
     * Retrieve information about a conversation.
     * Recommended usage: Conversation.getInfo
     * Documentation: https://api.slack.com/methods/conversations.info
     * @param options Request options.
     */
    getConversationInfo<T = Conversation.GetInfo.Response.OK>(options: Conversation.GetInfo.Options): Promise<Conversation.GetInfo.Response.OK>;
    /**
     * Invites users to a channel.
     * Recommended usage: Conversation.inviteUser
     * Documentation: https://api.slack.com/methods/conversations.invite
     * @param options Request options.
     */
    inviteUserToConversation<T = Conversation.InviteUser.Response.OK>(options: Conversation.InviteUser.Options): Promise<Conversation.InviteUser.Response.OK>;
    /**
     * Joins an existing conversation.
     * Recommended usage: Conversation.joinConversation
     * Documentation: https://api.slack.com/methods/conversations.join
     * @param options Request options.
     */
    joinConversation<T = Conversation.JoinConversation.Response.OK>(options: Conversation.JoinConversation.Options): Promise<Conversation.JoinConversation.Response.OK>;
    /**
     * Removes a user from a conversation.
     * Recommended usage: Conversation.kickUser
     * Documentation: https://api.slack.com/methods/conversations.kick
     * @param options Request options.
     */
    kickUserFromConversation<T = Conversation.KickUser.Response.OK>(options: Conversation.KickUser.Options): Promise<Conversation.KickUser.Response.OK>;
    /**
     * Leaves a conversation.
     * Recommended usage: Conversation.leaveConversation
     * Documentation: https://api.slack.com/methods/conversations.leave
     * @param options Request options.
     */
    leaveConversation<T = Conversation.LeaveConversation.Response.OK>(options: Conversation.LeaveConversation.Options): Promise<Conversation.LeaveConversation.Response.OK>;
    /**
     * Lists all channels in a Slack team.
     * Recommended usage: Conversation.getConversations
     * Documentation: https://api.slack.com/methods/conversations.list
     * @param options Request options.
     */
    getConversations<T = Conversation.GetConversations.Response.OK>(options?: Conversation.GetConversations.Options): Promise<Conversation.GetConversations.Response.OK>;
    /**
     * Retrieve members of a conversation.
     * Recommended usage: Conversation.getMembers
     * Documentation: https://api.slack.com/methods/conversations.members
     * @param options Request options.
     */
    getConversationMembers<T = Conversation.GetMembers.Response.OK>(options: Conversation.GetMembers.Options): Promise<Conversation.GetMembers.Response.OK>;
    /**
     * Opens or resumes a direct message or multi-person direct message.
     * Recommended usage: Conversation.openConversation
     * Documentation: https://api.slack.com/methods/conversations.open
     * @param options Request options.
     */
    openConversation<T = Conversation.OpenConversation.Response.OK>(options: Conversation.OpenConversation.Options): Promise<Conversation.OpenConversation.Response.OK>;
    /**
     * Renames a conversation.
     * Recommended usage: Conversation.renameConversation
     * Documentation: https://api.slack.com/methods/conversations.rename
     * @param options Request options.
     */
    renameConversation<T = Conversation.RenameConversation.Response.OK>(options: Conversation.RenameConversation.Options): Promise<Conversation.RenameConversation.Response.OK>;
    /**
     * Retrieve a thread of messages posted to a conversation
     * Recommended usage: Conversation.getReplies
     * Documentation: https://api.slack.com/methods/conversations.replies
     * @param options Request options.
     */
    getConversationReplies<T = Conversation.GetReplies.Response.OK>(options?: Conversation.GetReplies.Options): Promise<Conversation.GetReplies.Response.OK>;
    /**
     * Sets the purpose for a conversation.
     * Recommended usage: Conversation.setPurpose
     * Documentation: https://api.slack.com/methods/conversations.setPurpose
     * @param options Request options.
     */
    setConversationPurpose<T = Conversation.SetPurpose.Response.OK>(options: Conversation.SetPurpose.Options): Promise<Conversation.SetPurpose.Response.OK>;
    /**
     * Sets the topic for a conversation.
     * Recommended usage: Conversation.setTopic
     * Documentation: https://api.slack.com/methods/conversations.setTopic
     * @param options Request options.
     */
    setConversationTopic<T = Conversation.SetTopic.Response.OK>(options: Conversation.SetTopic.Options): Promise<Conversation.SetTopic.Response.OK>;
    /**
     * Reverses conversation archival.
     * Recommended usage: Conversation.unarchiveConversation
     * Documentation: https://api.slack.com/methods/conversations.unarchive
     * @param options Request options.
     */
    unarchiveConversation<T = Conversation.UnarchiveConversation.Response.OK>(options: Conversation.UnarchiveConversation.Options): Promise<Conversation.UnarchiveConversation.Response.OK>;
    /**
     * Open a dialog with a user
     * Recommended usage: Dialog.openDialog
     * Documentation: https://api.slack.com/methods/dialog.open
     * @param options Request options.
     */
    openDialog<T = Dialog.OpenDialog.Response.OK>(options: Dialog.OpenDialog.Options): Promise<Dialog.OpenDialog.Response.OK>;
    /**
     * Ends the current user's Do Not Disturb session immediately.
     * Recommended usage: Dnd.endDnd
     * Documentation: https://api.slack.com/methods/dnd.endDnd
     * @param options Request options.
     */
    endDnd<T = Dnd.EndDnd.Response.OK>(options?: Dnd.EndDnd.Options): Promise<Dnd.EndDnd.Response.OK>;
    /**
     * Ends the current user's snooze mode immediately.
     * Recommended usage: Dnd.endSnooze
     * Documentation: https://api.slack.com/methods/dnd.endSnooze
     * @param options Request options.
     */
    endDndSnooze<T = Dnd.EndSnooze.Response.OK>(options?: Dnd.EndSnooze.Options): Promise<Dnd.EndSnooze.Response.OK>;
    /**
     * Retrieves a user's current Do Not Disturb status.
     * Recommended usage: Dnd.getInfo
     * Documentation: https://api.slack.com/methods/dnd.info
     * @param options Request options.
     */
    getDndInfo<T = Dnd.GetInfo.Response.OK>(options?: Dnd.GetInfo.Options): Promise<Dnd.GetInfo.Response.OK>;
    /**
     * Turns on Do Not Disturb mode for the current user, or changes its duration.
     * Recommended usage: Dnd.setSnooze
     * Documentation: https://api.slack.com/methods/dnd.setSnooze
     * @param options Request options.
     */
    setDndSnooze<T = Dnd.SetSnooze.Response.OK>(options: Dnd.SetSnooze.Options): Promise<Dnd.SetSnooze.Response.OK>;
    /**
     * Retrieves the Do Not Disturb status for up to 50 users on a team.
     * Recommended usage: Dnd.getTeamInfo
     * Documentation: https://api.slack.com/methods/dnd.teamInfo
     * @param options Request options.
     */
    getDndTeamInfo<T = Dnd.GetTeamInfo.Response.OK>(options: Dnd.GetTeamInfo.Options): Promise<Dnd.GetTeamInfo.Response.OK>;
    /**
     * Lists custom emoji for a team.
     * Recommended usage: Emoji.getEmojis
     * Documentation: https://api.slack.com/methods/emoji.list
     * @param options Request options.
     */
    getEmojis<T = Emoji.GetEmojis.Response.OK>(options?: Emoji.GetEmojis.Options): Promise<Emoji.GetEmojis.Response.OK>;
    /**
     * Deletes a file.
     * Recommended usage: File.deleteFile
     * Documentation: https://api.slack.com/methods/files.delete
     * @param options Request options.
     */
    deleteFile<T = File.DeleteFile.Response.OK>(options: File.DeleteFile.Options): Promise<File.DeleteFile.Response.OK>;
    /**
     * Gets information about a file.
     * Recommended usage: File.getInfo
     * Documentation: https://api.slack.com/methods/files.info
     * @param options Request options.
     */
    getFileInfo<T = File.GetInfo.Response.OK>(options?: File.GetInfo.Options): Promise<File.GetInfo.Response.OK>;
    /**
     * List for a team, in a channel, or from a user with applied filters.
     * Recommended usage: File.getFiles
     * Documentation: https://api.slack.com/methods/files.list
     * @param options Request options.
     */
    getFiles<T = File.GetFiles.Response.OK>(options?: File.GetFiles.Options): Promise<File.GetFiles.Response.OK>;
    /**
     * Uploads or creates a file.
     * Recommended usage: File.uploadFile
     * Documentation: https://api.slack.com/methods/files.upload
     * @param options Request options.
     */
    uploadFile<T = File.UploadFile.Response.OK>(options: File.UploadFile.Options): Promise<File.UploadFile.Response.OK>;
    /**
     * Deletes an existing comment on a file.
     * Recommended usage: File.Comment.deleteComment
     * Documentation: https://api.slack.com/methods/files.comments.delete
     * @param options Request options.
     */
    deleteFileComment<T = File.Comment.DeleteComment.Response.OK>(options: File.Comment.DeleteComment.Options): Promise<File.Comment.DeleteComment.Response.OK>;
    /**
     * Revokes public/external sharing access for a file
     * Recommended usage: File.PublicUrl.revokePublicUrl
     * Documentation: https://api.slack.com/methods/files.revokePublicURL
     * @param options Request options.
     */
    revokeFilePublicUrl<T = File.PublicUrl.RevokePublicUrl.Response.OK>(options: File.PublicUrl.RevokePublicUrl.Options): Promise<File.PublicUrl.RevokePublicUrl.Response.OK>;
    /**
     * Enables a file for public/external sharing.
     * Recommended usage: File.PublicUrl.createPublicUrl
     * Documentation: https://api.slack.com/methods/files.sharedPublicURL
     * @param options Request options.
     */
    createFilePublicUrl<T = File.PublicUrl.CreatePublicUrl.Response.OK>(options: File.PublicUrl.CreatePublicUrl.Options): Promise<File.PublicUrl.CreatePublicUrl.Response.OK>;
    /**
     * Adds a file from a remote service
     * Recommended usage: File.Remote.addFile
     * Documentation: https://api.slack.com/methods/files.remote.add
     * @param options Request options.
     */
    addRemoteFile<T = File.Remote.AddFile.Response.OK>(options: File.Remote.AddFile.Options): Promise<File.Remote.AddFile.Response.OK>;
    /**
     * Retrieve information about a remote file added to Slack
     * Recommended usage: File.Remote.getInfo
     * Documentation: https://api.slack.com/methods/files.remote.info
     * @param options Request options.
     */
    getRemoteFileInfo<T = File.Remote.GetInfo.Response.OK>(options?: File.Remote.GetInfo.Options): Promise<File.Remote.GetInfo.Response.OK>;
    /**
     * Retrieve information about a remote file added to Slack
     * Recommended usage: File.Remote.getFiles
     * Documentation: https://api.slack.com/methods/files.remote.list
     * @param options Request options.
     */
    getRemoteFiles<T = File.Remote.GetFiles.Response.OK>(options?: File.Remote.GetFiles.Options): Promise<File.Remote.GetFiles.Response.OK>;
    /**
     * Remove a remote file.
     * Recommended usage: File.Remote.removeFile
     * Documentation: https://api.slack.com/methods/files.remote.remove
     * @param options Request options.
     */
    removeRemoteFile<T = File.Remote.RemoveFile.Response.OK>(options?: File.Remote.RemoveFile.Options): Promise<File.Remote.RemoveFile.Response.OK>;
    /**
     * Share a remote file into a channel.
     * Recommended usage: File.Remote.shareFile
     * Documentation: https://api.slack.com/methods/files.remote.share
     * @param options Request options.
     */
    shareRemoteFile<T = File.Remote.ShareFile.Response.OK>(options?: File.Remote.ShareFile.Options): Promise<File.Remote.ShareFile.Response.OK>;
    /**
     * Updates an existing remote file.
     * Recommended usage: File.Remote.updateFile
     * Documentation: https://api.slack.com/methods/files.remote.update
     * @param options Request options.
     */
    updateRemoteFile<T = File.Remote.UpdateFile.Response.OK>(options?: File.Remote.UpdateFile.Options): Promise<File.Remote.UpdateFile.Response.OK>;
    /**
     * Adds a reaction to an item.
     * Recommended usage: Reaction.addReaction
     * Documentation: https://api.slack.com/methods/reactions.add
     * @param options Request options.
     */
    addReaction<T = Reaction.AddReaction.Response.OK>(options: Reaction.AddReaction.Options): Promise<Reaction.AddReaction.Response.OK>;
    /**
     * Gets reactions for an item.
     * Recommended usage: Reaction.getReaction
     * Documentation: https://api.slack.com/methods/reactions.get
     * @param options Request options.
     */
    getReaction<T = Reaction.GetReaction.Response.OK>(options?: Reaction.GetReaction.Options): Promise<Reaction.GetReaction.Response.OK>;
    /**
     * Lists reactions made by a user.
     * Recommended usage: Reaction.getReactions
     * Documentation: https://api.slack.com/methods/reactions.list
     * @param options Request options.
     */
    getReactions<T = Reaction.GetReactions.Response.OK>(options?: Reaction.GetReactions.Options): Promise<Reaction.GetReactions.Response.OK>;
    /**
     * Removes a reaction from an item.
     * Recommended usage: Reaction.removeReaction
     * Documentation: https://api.slack.com/methods/reactions.remove
     * @param options Request options.
     */
    removeReaction<T = Reaction.RemoveReaction.Response.OK>(options: Reaction.RemoveReaction.Options): Promise<Reaction.RemoveReaction.Response.OK>;
    /**
     * Searches for messages matching a query.
     * Recommended usage: Search.searchMessages
     * Documentation: https://api.slack.com/methods/search.messages
     * @param options Request options.
     */
    searchMessages<T = Search.SearchMessages.Response.OK>(options: Search.SearchMessages.Options): Promise<Search.SearchMessages.Response.OK>;
    /**
     * Gets the access logs for the current team.
     * Recommended usage: Team.getAccessLogs
     * Documentation: https://api.slack.com/methods/team.accessLogs
     * @param options Request options.
     */
    getTeamAccessLogs<T = Team.GetAccessLogs.Response.OK>(options?: Team.GetAccessLogs.Options): Promise<Team.GetAccessLogs.Response.OK>;
    /**
     * Gets billable users information for the current team.
     * Recommended usage: Team.getBillableInfo
     * Documentation: https://api.slack.com/methods/team.billableInfo
     * @param options Request options.
     */
    getTeamBillableInfo<T = Team.GetBillableInfo.Response.OK>(options?: Team.GetBillableInfo.Options): Promise<Team.GetBillableInfo.Response.OK>;
    /**
     * Gets information about the current team.
     * Recommended usage: Team.getInfo
     * Documentation: https://api.slack.com/methods/team.info
     * @param options Request options.
     */
    getTeamInfo<T = Team.GetInfo.Response.OK>(options?: Team.GetInfo.Options): Promise<Team.GetInfo.Response.OK>;
    /**
     * Gets the integration logs for the current team.
     * Recommended usage: Team.getIntegrationLogs
     * Documentation: https://api.slack.com/methods/team.integrationLogs
     * @param options Request options.
     */
    getTeamIntegrationLogs<T = Team.GetIntegrationLogs.Response.OK>(options?: Team.GetIntegrationLogs.Options): Promise<Team.GetIntegrationLogs.Response.OK>;
    /**
     * Retrieve a team's profile.
     * Recommended usage: Team.Profile.getProfile
     * Documentation: https://api.slack.com/methods/team.profile.get
     * @param options Request options.
     */
    getTeamProfile<T = Team.Profile.GetProfile.Response.OK>(options?: Team.Profile.GetProfile.Options): Promise<Team.Profile.GetProfile.Response.OK>;
    /**
     * Create a User Group
     * Recommended usage: UserGroup.createUserGroup
     * Documentation: https://api.slack.com/methods/usergroups.create
     * @param options Request options.
     */
    createUserGroup<T = UserGroup.CreateUserGroup.Response.OK>(options: UserGroup.CreateUserGroup.Options): Promise<UserGroup.CreateUserGroup.Response.OK>;
    /**
     * Disable an existing User Group
     * Recommended usage: UserGroup.disableUserGroup
     * Documentation: https://api.slack.com/methods/usergroups.disable
     * @param options Request options.
     */
    disableUserGroup<T = UserGroup.DisableUserGroup.Response.OK>(options: UserGroup.DisableUserGroup.Options): Promise<UserGroup.DisableUserGroup.Response.OK>;
    /**
     * Enable a User Group
     * Recommended usage: UserGroup.enableUserGroup
     * Documentation: https://api.slack.com/methods/usergroups.enable
     * @param options Request options.
     */
    enableUserGroup<T = UserGroup.EnableUserGroup.Response.OK>(options: UserGroup.EnableUserGroup.Options): Promise<UserGroup.EnableUserGroup.Response.OK>;
    /**
     * List all User Groups for a team
     * Recommended usage: UserGroup.getUserGroups
     * Documentation: https://api.slack.com/methods/usergroups.list
     * @param options Request options.
     */
    getUserGroups<T = UserGroup.GetUserGroups.Response.OK>(options?: UserGroup.GetUserGroups.Options): Promise<UserGroup.GetUserGroups.Response.OK>;
    /**
     * Update an existing User Group
     * Recommended usage: UserGroup.updateUserGroup
     * Documentation: https://api.slack.com/methods/usergroups.update
     * @param options Request options.
     */
    updateUserGroup<T = UserGroup.UpdateUserGroup.Response.OK>(options: UserGroup.UpdateUserGroup.Options): Promise<UserGroup.UpdateUserGroup.Response.OK>;
    /**
     * List all users in a User Group
     * Recommended usage: UserGroup.User.getUsers
     * Documentation: https://api.slack.com/methods/usergroups.users.list
     * @param options Request options.
     */
    getUsersInUserGroup<T = UserGroup.User.GetUsers.Response.OK>(options: UserGroup.User.GetUsers.Options): Promise<UserGroup.User.GetUsers.Response.OK>;
    /**
     * Update the list of users for a User Group
     * Recommended usage: UserGroup.User.updateUsers
     * Documentation: https://api.slack.com/methods/usergroups.users.update
     * @param options Request options.
     */
    updateUsersInUserGroup<T = UserGroup.User.UpdateUsers.Response.OK>(options: UserGroup.User.UpdateUsers.Options): Promise<UserGroup.User.UpdateUsers.Response.OK>;
    /**
     * Send message back to Slack using the response_url in the event payload.
     * Recommended usage: Reply.postMessage
     * Documentation: https://api.slack.com/interactivity/handling#message_responses
     * @param options Request options.
     */
    postReplyMessage<T = Reply.PostMessage.Response.OK>(options: Reply.PostMessage.Options): Promise<Reply.PostMessage.Response.OK>;
}
declare class AllUserGroup extends BaseGroup {
    constructor(connection: string, options: ConnectionOptions);
    /**
     * Set an existing guest user, admin user, or owner to be a regular user.
     * Recommended usage: Admin.Users.setRegular
     * Documentation: https://api.slack.com/methods/admin.users.setRegular
     * @param options Request options.
     */
    adminSetRegularUser<T = Admin.Users.SetRegular.Response.OK>(options: Admin.Users.SetRegular.Options): Promise<Admin.Users.SetRegular.Response.OK>;
    /**
     * Set an existing guest, regular user, or admin user to be a workspace owner.
     * Recommended usage: Admin.Users.setOwner
     * Documentation: https://api.slack.com/methods/admin.users.setOwner
     * @param options Request options.
     */
    adminSetOwnerUser<T = Admin.Users.SetOwner.Response.OK>(options: Admin.Users.SetOwner.Options): Promise<Admin.Users.SetOwner.Response.OK>;
    /**
     * Set an expiration for a guest user
     * Recommended usage: Admin.Users.setExpiration
     * Documentation: https://api.slack.com/methods/admin.users.setExpiration
     * @param options Request options.
     */
    adminSetUserExpiration<T = Admin.Users.SetExpiration.Response.OK>(options: Admin.Users.SetExpiration.Options): Promise<Admin.Users.SetExpiration.Response.OK>;
    /**
     * Set an existing guest, regular user, or owner to be an admin user.
     * Recommended usage: Admin.Users.setAdmin
     * Documentation: https://api.slack.com/methods/admin.users.setAdmin
     * @param options Request options.
     */
    adminSetAdminUser<T = Admin.Users.SetAdmin.Response.OK>(options: Admin.Users.SetAdmin.Options): Promise<Admin.Users.SetAdmin.Response.OK>;
    /**
     * Remove a user from a workspace.
     * Recommended usage: Admin.Users.removeUser
     * Documentation: https://api.slack.com/methods/admin.users.remove
     * @param options Request options.
     */
    adminRemoveUser<T = Admin.Users.RemoveUser.Response.OK>(options: Admin.Users.RemoveUser.Options): Promise<Admin.Users.RemoveUser.Response.OK>;
    /**
     * List users on a workspace
     * Recommended usage: Admin.Users.getUsers
     * Documentation: https://api.slack.com/methods/admin.users.list
     * @param options Request options.
     */
    adminGetUsers<T = Admin.Users.GetUsers.Response.OK>(options: Admin.Users.GetUsers.Options): Promise<Admin.Users.GetUsers.Response.OK>;
    /**
     * Invite a user to a workspace.
     * Recommended usage: Admin.Users.inviteUser
     * Documentation: https://api.slack.com/methods/admin.users.invite
     * @param options Request options.
     */
    adminInviteUser<T = Admin.Users.InviteUser.Response.OK>(options: Admin.Users.InviteUser.Options): Promise<Admin.Users.InviteUser.Response.OK>;
    /**
     * Add an Enterprise user to a workspace.
     * Recommended usage: Admin.Users.assignUser
     * Documentation: https://api.slack.com/methods/admin.users.assign
     * @param options Request options.
     */
    adminAssignUser<T = Admin.Users.AssignUser.Response.OK>(options: Admin.Users.AssignUser.Options): Promise<Admin.Users.AssignUser.Response.OK>;
    /**
     * Update an existing view.
     * Recommended usage: View.updateView
     * Documentation: https://api.slack.com/methods/views.update
     * @param options Request options.
     */
    updateView<T = View.UpdateView.Response.OK>(options: View.UpdateView.Options): Promise<View.UpdateView.Response.OK>;
    /**
     * Push a view onto the stack of a root view.
     * Recommended usage: View.pushView
     * Documentation: https://api.slack.com/methods/views.push
     * @param options Request options.
     */
    pushView<T = View.PushView.Response.OK>(options: View.PushView.Options): Promise<View.PushView.Response.OK>;
    /**
     * Open a view for a user.
     * Recommended usage: View.openView
     * Documentation: https://api.slack.com/methods/views.open
     * @param options Request options.
     */
    openView<T = View.OpenView.Response.OK>(options: View.OpenView.Options): Promise<View.OpenView.Response.OK>;
    /**
     * Find a user with an email address.
     * Recommended usage: User.getUserByEmail
     * Documentation: https://api.slack.com/methods/users.lookupByEmail
     * @param options Request options.
     */
    getUserByEmail<T = User.GetUserByEmail.Response.OK>(options: User.GetUserByEmail.Options): Promise<User.GetUserByEmail.Response.OK>;
    /**
     * Lists all users in a Slack team.
     * Recommended usage: User.getUsers
     * Documentation: https://api.slack.com/methods/users.list
     * @param options Request options.
     */
    getUsers<T = User.GetUsers.Response.OK>(options?: User.GetUsers.Options): Promise<User.GetUsers.Response.OK>;
    /**
     * Gets information about a user.
     * Recommended usage: User.getInfo
     * Documentation: https://api.slack.com/methods/users.info
     * @param options Request options.
     */
    getUserInfo<T = User.GetInfo.Response.OK>(options: User.GetInfo.Options): Promise<User.GetInfo.Response.OK>;
    /**
     * Get a user's identity.
     * Recommended usage: User.getIdentity
     * Documentation: https://api.slack.com/methods/users.identity
     * @param options Request options.
     */
    getUserIdentity<T = User.GetIdentity.Response.OK>(options?: User.GetIdentity.Options): Promise<any>;
    /**
     * List conversations the calling user may access.
     * Recommended usage: User.getConversations
     * Documentation: https://api.slack.com/methods/users.conversations
     * @param options Request options.
     */
    getUserConversations<T = User.GetConversations.Response.OK>(options?: User.GetConversations.Options): Promise<User.GetConversations.Response.OK>;
    /**
     * Gets user presence information.
     * Recommended usage: User.getPresence
     * Documentation: https://api.slack.com/methods/users.getPresence
     * @param options Request options.
     */
    getUserPresence<T = User.GetPresence.Response.OK>(options?: User.GetPresence.Options): Promise<User.GetPresence.Response.OK>;
    /**
     * Manually sets user presence.
     * Recommended usage: User.setPresence
     * Documentation: https://api.slack.com/methods/users.setPresence
     * @param options Request options.
     */
    setUserPresence<T = User.SetPresence.Response.OK>(options: User.SetPresence.Options): Promise<User.SetPresence.Response.OK>;
    /**
     * Set the profile information for a user.
     * Recommended usage: User.Profile.setProfile
     * Documentation: https://api.slack.com/methods/users.profile.set
     * @param options Request options.
     */
    setUserProfile<T = User.Profile.SetProfile.Response.OK>(options: User.Profile.SetProfile.Options): Promise<User.Profile.SetProfile.Response.OK>;
    /**
     * Retrieves a user's profile information.
     * Recommended usage: User.Profile.getProfile
     * Documentation: https://api.slack.com/methods/users.profile.get
     * @param options Request options.
     */
    getUserProfile<T = User.Profile.GetProfile.Response.OK>(options?: User.Profile.GetProfile.Options): Promise<User.Profile.GetProfile.Response.OK>;
    /**
     * Lists all reminders created by or for a given user.
     * Recommended usage: Reminders.getReminders
     * Documentation: https://api.slack.com/methods/reminders.list
     * @param options Request options.
     */
    getReminders<T = Reminders.GetReminders.Response.OK>(options?: Reminders.GetReminders.Options): Promise<Reminders.GetReminders.Response.OK>;
    /**
     * Gets information about a reminder.
     * Recommended usage: Reminders.getInfo
     * Documentation: https://api.slack.com/methods/reminders.info
     * @param options Request options.
     */
    getReminderInfo<T = Reminders.GetInfo.Response.OK>(options: Reminders.GetInfo.Options): Promise<Reminders.GetInfo.Response.OK>;
    /**
     * Deletes a reminder.
     * Recommended usage: Reminders.deleteReminder
     * Documentation: https://api.slack.com/methods/reminders.delete
     * @param options Request options.
     */
    deleteReminder<T = Reminders.DeleteReminder.Response.OK>(options: Reminders.DeleteReminder.Options): Promise<Reminders.DeleteReminder.Response.OK>;
    /**
     * Marks a reminder as complete.
     * Recommended usage: Reminders.completeReminder
     * Documentation: https://api.slack.com/methods/reminders.complete
     * @param options Request options.
     */
    completeReminder<T = Reminders.CompleteReminder.Response.OK>(options: Reminders.CompleteReminder.Options): Promise<Reminders.CompleteReminder.Response.OK>;
    /**
     * Creates a reminder.
     * Recommended usage: Reminders.addReminder
     * Documentation: https://api.slack.com/methods/reminders.add
     * @param options Request options.
     */
    addReminder<T = Reminders.AddReminder.Response.OK>(options: Reminders.AddReminder.Options): Promise<Reminders.AddReminder.Response.OK>;
    /**
     * Un-pins an item from a channel.
     * Recommended usage: Pins.removePin
     * Documentation: https://api.slack.com/methods/pins.remove
     * @param options Request options.
     */
    removePin<T = Pins.RemovePin.Response.OK>(options: Pins.RemovePin.Options): Promise<Pins.RemovePin.Response.OK>;
    /**
     * Lists items pinned to a channel.
     * Recommended usage: Pins.getPins
     * Documentation: https://api.slack.com/methods/pins.list
     * @param options Request options.
     */
    getPins<T = Pins.GetPins.Response.OK>(options: Pins.GetPins.Options): Promise<any>;
    /**
     * Pins an item to a channel.
     * Recommended usage: Pins.addPin
     * Documentation: https://api.slack.com/methods/pins.add
     * @param options Request options.
     */
    addPin<T = Pins.AddPin.Response.OK>(options: Pins.AddPin.Options): Promise<Pins.AddPin.Response.OK>;
    /**
     * Gets information about a bot user.
     * Recommended usage: Bot.getInfo
     * Documentation: https://api.slack.com/methods/bots.info
     * @param options Request options.
     */
    getBotInfo<T = Bot.GetInfo.Response.OK>(options?: Bot.GetInfo.Options): Promise<Bot.GetInfo.Response.OK>;
    /**
     * Deletes a message.
     * Recommended usage: Chat.deleteMessage
     * Documentation: https://api.slack.com/methods/chat.delete
     * @param options Request options.
     */
    deleteChatMessage<T = Chat.DeleteMessage.Response.OK>(options: Chat.DeleteMessage.Options): Promise<Chat.DeleteMessage.Response.OK>;
    /**
     * Deletes a pending scheduled message from the queue.
     * Recommended usage: Chat.deleteScheduledMessage
     * Documentation: https://api.slack.com/methods/chat.deleteScheduledMessage
     * @param options Request options.
     */
    deleteChatScheduledMessage<T = Chat.DeleteScheduledMessage.Response.OK>(options: Chat.DeleteScheduledMessage.Options): Promise<Chat.DeleteScheduledMessage.Response.OK>;
    /**
     * Retrieve a permalink URL for a specific extant message
     * Recommended usage: Chat.getPermalink
     * Documentation: https://api.slack.com/methods/chat.getPermalink
     * @param options Request options.
     */
    getChatPermalink<T = Chat.GetPermalink.Response.OK>(options: Chat.GetPermalink.Options): Promise<Chat.GetPermalink.Response.OK>;
    /**
     * Share a me message into a channel.
     * Recommended usage: Chat.postMeMessage
     * Documentation: https://api.slack.com/methods/chat.meMessage
     * @param options Request options.
     */
    postChatMeMessage<T = Chat.PostMeMessage.Response.OK>(options: Chat.PostMeMessage.Options): Promise<Chat.PostMeMessage.Response.OK>;
    /**
     * Sends an ephemeral message to a user in a channel.
     * Recommended usage: Chat.postEphemeralMessage
     * Documentation: https://api.slack.com/methods/chat.postEphemeral
     * @param options Request options.
     */
    postChatEphemeralMessage<T = Chat.PostEphemeralMessage.Response.OK>(options: Chat.PostEphemeralMessage.Options): Promise<Chat.PostEphemeralMessage.Response.OK>;
    /**
     * Sends a message to a channel.
     * Recommended usage: Chat.postMessage
     * Documentation: https://api.slack.com/methods/chat.postMessage
     * @param options Request options.
     */
    postChatMessage<T = Chat.PostMessage.Response.OK>(options: Chat.PostMessage.Options): Promise<Chat.PostMessage.Response.OK>;
    /**
     * Schedules a message to be sent to a channel.
     * Recommended usage: Chat.scheduleMessage
     * Documentation: https://api.slack.com/methods/chat.scheduleMessage
     * @param options Request options.
     */
    scheduleChatMessage<T = Chat.ScheduleMessage.Response.OK>(options: Chat.ScheduleMessage.Options): Promise<Chat.ScheduleMessage.Response.OK>;
    /**
     * Provide custom unfurl behavior for user-posted URLs
     * Recommended usage: Chat.unfurlMessage
     * Documentation: https://api.slack.com/methods/chat.unfurl
     * @param options Request options.
     */
    unfurlChatMessage<T = Chat.UnfurlMessage.Response.OK>(options: Chat.UnfurlMessage.Options): Promise<Chat.UnfurlMessage.Response.OK>;
    /**
     * Updates a message.
     * Recommended usage: Chat.updateMessage
     * Documentation: https://api.slack.com/methods/chat.update
     * @param options Request options.
     */
    updateChatMessage<T = Chat.UpdateMessage.Response.OK>(options: Chat.UpdateMessage.Options): Promise<Chat.UpdateMessage.Response.OK>;
    /**
     * Returns a list of scheduled messages.
     * Recommended usage: Chat.ScheduledMessage.getScheduledMessages
     * Documentation: https://api.slack.com/methods/chat.scheduledMessages.list
     * @param options Request options.
     */
    getChatScheduledMessages<T = Chat.ScheduledMessage.GetScheduledMessages.Response.OK>(options?: Chat.ScheduledMessage.GetScheduledMessages.Options): Promise<Chat.ScheduledMessage.GetScheduledMessages.Response.OK>;
    /**
     * Archives a conversation.
     * Recommended usage: Conversation.archiveConversation
     * Documentation: https://api.slack.com/methods/conversations.archive
     * @param options Request options.
     */
    archiveConversation<T = Conversation.ArchiveConversation.Response.OK>(options: Conversation.ArchiveConversation.Options): Promise<Conversation.ArchiveConversation.Response.OK>;
    /**
     * Closes a direct message or multi-person direct message.
     * Recommended usage: Conversation.closeConversation
     * Documentation: https://api.slack.com/methods/conversations.close
     * @param options Request options.
     */
    closeConversation<T = Conversation.CloseConversation.Response.OK>(options: Conversation.CloseConversation.Options): Promise<Conversation.CloseConversation.Response.OK>;
    /**
     * Initiates a public or private channel-based conversation
     * Recommended usage: Conversation.createConversation
     * Documentation: https://api.slack.com/methods/conversations.create
     * @param options Request options.
     */
    createConversation<T = Conversation.CreateConversation.Response.OK>(options: Conversation.CreateConversation.Options): Promise<Conversation.CreateConversation.Response.OK>;
    /**
     * Fetches a conversation's history of messages and events.
     * Recommended usage: Conversation.getHistory
     * Documentation: https://api.slack.com/methods/conversations.history
     * @param options Request options.
     */
    getConversationHistory<T = Conversation.GetHistory.Response.OK>(options?: Conversation.GetHistory.Options): Promise<Conversation.GetHistory.Response.OK>;
    /**
     * Retrieve information about a conversation.
     * Recommended usage: Conversation.getInfo
     * Documentation: https://api.slack.com/methods/conversations.info
     * @param options Request options.
     */
    getConversationInfo<T = Conversation.GetInfo.Response.OK>(options: Conversation.GetInfo.Options): Promise<Conversation.GetInfo.Response.OK>;
    /**
     * Invites users to a channel.
     * Recommended usage: Conversation.inviteUser
     * Documentation: https://api.slack.com/methods/conversations.invite
     * @param options Request options.
     */
    inviteUserToConversation<T = Conversation.InviteUser.Response.OK>(options: Conversation.InviteUser.Options): Promise<Conversation.InviteUser.Response.OK>;
    /**
     * Joins an existing conversation.
     * Recommended usage: Conversation.joinConversation
     * Documentation: https://api.slack.com/methods/conversations.join
     * @param options Request options.
     */
    joinConversation<T = Conversation.JoinConversation.Response.OK>(options: Conversation.JoinConversation.Options): Promise<Conversation.JoinConversation.Response.OK>;
    /**
     * Removes a user from a conversation.
     * Recommended usage: Conversation.kickUser
     * Documentation: https://api.slack.com/methods/conversations.kick
     * @param options Request options.
     */
    kickUserFromConversation<T = Conversation.KickUser.Response.OK>(options: Conversation.KickUser.Options): Promise<Conversation.KickUser.Response.OK>;
    /**
     * Leaves a conversation.
     * Recommended usage: Conversation.leaveConversation
     * Documentation: https://api.slack.com/methods/conversations.leave
     * @param options Request options.
     */
    leaveConversation<T = Conversation.LeaveConversation.Response.OK>(options: Conversation.LeaveConversation.Options): Promise<Conversation.LeaveConversation.Response.OK>;
    /**
     * Lists all channels in a Slack team.
     * Recommended usage: Conversation.getConversations
     * Documentation: https://api.slack.com/methods/conversations.list
     * @param options Request options.
     */
    getConversations<T = Conversation.GetConversations.Response.OK>(options?: Conversation.GetConversations.Options): Promise<Conversation.GetConversations.Response.OK>;
    /**
     * Retrieve members of a conversation.
     * Recommended usage: Conversation.getMembers
     * Documentation: https://api.slack.com/methods/conversations.members
     * @param options Request options.
     */
    getConversationMembers<T = Conversation.GetMembers.Response.OK>(options: Conversation.GetMembers.Options): Promise<Conversation.GetMembers.Response.OK>;
    /**
     * Opens or resumes a direct message or multi-person direct message.
     * Recommended usage: Conversation.openConversation
     * Documentation: https://api.slack.com/methods/conversations.open
     * @param options Request options.
     */
    openConversation<T = Conversation.OpenConversation.Response.OK>(options: Conversation.OpenConversation.Options): Promise<Conversation.OpenConversation.Response.OK>;
    /**
     * Renames a conversation.
     * Recommended usage: Conversation.renameConversation
     * Documentation: https://api.slack.com/methods/conversations.rename
     * @param options Request options.
     */
    renameConversation<T = Conversation.RenameConversation.Response.OK>(options: Conversation.RenameConversation.Options): Promise<Conversation.RenameConversation.Response.OK>;
    /**
     * Retrieve a thread of messages posted to a conversation
     * Recommended usage: Conversation.getReplies
     * Documentation: https://api.slack.com/methods/conversations.replies
     * @param options Request options.
     */
    getConversationReplies<T = Conversation.GetReplies.Response.OK>(options?: Conversation.GetReplies.Options): Promise<Conversation.GetReplies.Response.OK>;
    /**
     * Sets the purpose for a conversation.
     * Recommended usage: Conversation.setPurpose
     * Documentation: https://api.slack.com/methods/conversations.setPurpose
     * @param options Request options.
     */
    setConversationPurpose<T = Conversation.SetPurpose.Response.OK>(options: Conversation.SetPurpose.Options): Promise<Conversation.SetPurpose.Response.OK>;
    /**
     * Sets the topic for a conversation.
     * Recommended usage: Conversation.setTopic
     * Documentation: https://api.slack.com/methods/conversations.setTopic
     * @param options Request options.
     */
    setConversationTopic<T = Conversation.SetTopic.Response.OK>(options: Conversation.SetTopic.Options): Promise<Conversation.SetTopic.Response.OK>;
    /**
     * Reverses conversation archival.
     * Recommended usage: Conversation.unarchiveConversation
     * Documentation: https://api.slack.com/methods/conversations.unarchive
     * @param options Request options.
     */
    unarchiveConversation<T = Conversation.UnarchiveConversation.Response.OK>(options: Conversation.UnarchiveConversation.Options): Promise<Conversation.UnarchiveConversation.Response.OK>;
    /**
     * Open a dialog with a user
     * Recommended usage: Dialog.openDialog
     * Documentation: https://api.slack.com/methods/dialog.open
     * @param options Request options.
     */
    openDialog<T = Dialog.OpenDialog.Response.OK>(options: Dialog.OpenDialog.Options): Promise<Dialog.OpenDialog.Response.OK>;
    /**
     * Ends the current user's Do Not Disturb session immediately.
     * Recommended usage: Dnd.endDnd
     * Documentation: https://api.slack.com/methods/dnd.endDnd
     * @param options Request options.
     */
    endDnd<T = Dnd.EndDnd.Response.OK>(options?: Dnd.EndDnd.Options): Promise<Dnd.EndDnd.Response.OK>;
    /**
     * Ends the current user's snooze mode immediately.
     * Recommended usage: Dnd.endSnooze
     * Documentation: https://api.slack.com/methods/dnd.endSnooze
     * @param options Request options.
     */
    endDndSnooze<T = Dnd.EndSnooze.Response.OK>(options?: Dnd.EndSnooze.Options): Promise<Dnd.EndSnooze.Response.OK>;
    /**
     * Retrieves a user's current Do Not Disturb status.
     * Recommended usage: Dnd.getInfo
     * Documentation: https://api.slack.com/methods/dnd.info
     * @param options Request options.
     */
    getDndInfo<T = Dnd.GetInfo.Response.OK>(options?: Dnd.GetInfo.Options): Promise<Dnd.GetInfo.Response.OK>;
    /**
     * Turns on Do Not Disturb mode for the current user, or changes its duration.
     * Recommended usage: Dnd.setSnooze
     * Documentation: https://api.slack.com/methods/dnd.setSnooze
     * @param options Request options.
     */
    setDndSnooze<T = Dnd.SetSnooze.Response.OK>(options: Dnd.SetSnooze.Options): Promise<Dnd.SetSnooze.Response.OK>;
    /**
     * Retrieves the Do Not Disturb status for up to 50 users on a team.
     * Recommended usage: Dnd.getTeamInfo
     * Documentation: https://api.slack.com/methods/dnd.teamInfo
     * @param options Request options.
     */
    getDndTeamInfo<T = Dnd.GetTeamInfo.Response.OK>(options: Dnd.GetTeamInfo.Options): Promise<Dnd.GetTeamInfo.Response.OK>;
    /**
     * Lists custom emoji for a team.
     * Recommended usage: Emoji.getEmojis
     * Documentation: https://api.slack.com/methods/emoji.list
     * @param options Request options.
     */
    getEmojis<T = Emoji.GetEmojis.Response.OK>(options?: Emoji.GetEmojis.Options): Promise<Emoji.GetEmojis.Response.OK>;
    /**
     * Deletes a file.
     * Recommended usage: File.deleteFile
     * Documentation: https://api.slack.com/methods/files.delete
     * @param options Request options.
     */
    deleteFile<T = File.DeleteFile.Response.OK>(options: File.DeleteFile.Options): Promise<File.DeleteFile.Response.OK>;
    /**
     * Gets information about a file.
     * Recommended usage: File.getInfo
     * Documentation: https://api.slack.com/methods/files.info
     * @param options Request options.
     */
    getFileInfo<T = File.GetInfo.Response.OK>(options?: File.GetInfo.Options): Promise<File.GetInfo.Response.OK>;
    /**
     * List for a team, in a channel, or from a user with applied filters.
     * Recommended usage: File.getFiles
     * Documentation: https://api.slack.com/methods/files.list
     * @param options Request options.
     */
    getFiles<T = File.GetFiles.Response.OK>(options?: File.GetFiles.Options): Promise<File.GetFiles.Response.OK>;
    /**
     * Uploads or creates a file.
     * Recommended usage: File.uploadFile
     * Documentation: https://api.slack.com/methods/files.upload
     * @param options Request options.
     */
    uploadFile<T = File.UploadFile.Response.OK>(options: File.UploadFile.Options): Promise<File.UploadFile.Response.OK>;
    /**
     * Deletes an existing comment on a file.
     * Recommended usage: File.Comment.deleteComment
     * Documentation: https://api.slack.com/methods/files.comments.delete
     * @param options Request options.
     */
    deleteFileComment<T = File.Comment.DeleteComment.Response.OK>(options: File.Comment.DeleteComment.Options): Promise<File.Comment.DeleteComment.Response.OK>;
    /**
     * Revokes public/external sharing access for a file
     * Recommended usage: File.PublicUrl.revokePublicUrl
     * Documentation: https://api.slack.com/methods/files.revokePublicURL
     * @param options Request options.
     */
    revokeFilePublicUrl<T = File.PublicUrl.RevokePublicUrl.Response.OK>(options: File.PublicUrl.RevokePublicUrl.Options): Promise<File.PublicUrl.RevokePublicUrl.Response.OK>;
    /**
     * Enables a file for public/external sharing.
     * Recommended usage: File.PublicUrl.createPublicUrl
     * Documentation: https://api.slack.com/methods/files.sharedPublicURL
     * @param options Request options.
     */
    createFilePublicUrl<T = File.PublicUrl.CreatePublicUrl.Response.OK>(options: File.PublicUrl.CreatePublicUrl.Options): Promise<File.PublicUrl.CreatePublicUrl.Response.OK>;
    /**
     * Retrieve information about a remote file added to Slack
     * Recommended usage: File.Remote.getInfo
     * Documentation: https://api.slack.com/methods/files.remote.info
     * @param options Request options.
     */
    getRemoteFileInfo<T = File.Remote.GetInfo.Response.OK>(options?: File.Remote.GetInfo.Options): Promise<File.Remote.GetInfo.Response.OK>;
    /**
     * Retrieve information about a remote file added to Slack
     * Recommended usage: File.Remote.getFiles
     * Documentation: https://api.slack.com/methods/files.remote.list
     * @param options Request options.
     */
    getRemoteFiles<T = File.Remote.GetFiles.Response.OK>(options?: File.Remote.GetFiles.Options): Promise<File.Remote.GetFiles.Response.OK>;
    /**
     * Share a remote file into a channel.
     * Recommended usage: File.Remote.shareFile
     * Documentation: https://api.slack.com/methods/files.remote.share
     * @param options Request options.
     */
    shareRemoteFile<T = File.Remote.ShareFile.Response.OK>(options?: File.Remote.ShareFile.Options): Promise<File.Remote.ShareFile.Response.OK>;
    /**
     * Adds a reaction to an item.
     * Recommended usage: Reaction.addReaction
     * Documentation: https://api.slack.com/methods/reactions.add
     * @param options Request options.
     */
    addReaction<T = Reaction.AddReaction.Response.OK>(options: Reaction.AddReaction.Options): Promise<Reaction.AddReaction.Response.OK>;
    /**
     * Gets reactions for an item.
     * Recommended usage: Reaction.getReaction
     * Documentation: https://api.slack.com/methods/reactions.get
     * @param options Request options.
     */
    getReaction<T = Reaction.GetReaction.Response.OK>(options?: Reaction.GetReaction.Options): Promise<Reaction.GetReaction.Response.OK>;
    /**
     * Lists reactions made by a user.
     * Recommended usage: Reaction.getReactions
     * Documentation: https://api.slack.com/methods/reactions.list
     * @param options Request options.
     */
    getReactions<T = Reaction.GetReactions.Response.OK>(options?: Reaction.GetReactions.Options): Promise<Reaction.GetReactions.Response.OK>;
    /**
     * Removes a reaction from an item.
     * Recommended usage: Reaction.removeReaction
     * Documentation: https://api.slack.com/methods/reactions.remove
     * @param options Request options.
     */
    removeReaction<T = Reaction.RemoveReaction.Response.OK>(options: Reaction.RemoveReaction.Options): Promise<Reaction.RemoveReaction.Response.OK>;
    /**
     * Searches for messages matching a query.
     * Recommended usage: Search.searchMessages
     * Documentation: https://api.slack.com/methods/search.messages
     * @param options Request options.
     */
    searchMessages<T = Search.SearchMessages.Response.OK>(options: Search.SearchMessages.Options): Promise<Search.SearchMessages.Response.OK>;
    /**
     * Gets the access logs for the current team.
     * Recommended usage: Team.getAccessLogs
     * Documentation: https://api.slack.com/methods/team.accessLogs
     * @param options Request options.
     */
    getTeamAccessLogs<T = Team.GetAccessLogs.Response.OK>(options?: Team.GetAccessLogs.Options): Promise<Team.GetAccessLogs.Response.OK>;
    /**
     * Gets billable users information for the current team.
     * Recommended usage: Team.getBillableInfo
     * Documentation: https://api.slack.com/methods/team.billableInfo
     * @param options Request options.
     */
    getTeamBillableInfo<T = Team.GetBillableInfo.Response.OK>(options?: Team.GetBillableInfo.Options): Promise<Team.GetBillableInfo.Response.OK>;
    /**
     * Gets information about the current team.
     * Recommended usage: Team.getInfo
     * Documentation: https://api.slack.com/methods/team.info
     * @param options Request options.
     */
    getTeamInfo<T = Team.GetInfo.Response.OK>(options?: Team.GetInfo.Options): Promise<Team.GetInfo.Response.OK>;
    /**
     * Gets the integration logs for the current team.
     * Recommended usage: Team.getIntegrationLogs
     * Documentation: https://api.slack.com/methods/team.integrationLogs
     * @param options Request options.
     */
    getTeamIntegrationLogs<T = Team.GetIntegrationLogs.Response.OK>(options?: Team.GetIntegrationLogs.Options): Promise<Team.GetIntegrationLogs.Response.OK>;
    /**
     * Retrieve a team's profile.
     * Recommended usage: Team.Profile.getProfile
     * Documentation: https://api.slack.com/methods/team.profile.get
     * @param options Request options.
     */
    getTeamProfile<T = Team.Profile.GetProfile.Response.OK>(options?: Team.Profile.GetProfile.Options): Promise<Team.Profile.GetProfile.Response.OK>;
    /**
     * Create a User Group
     * Recommended usage: UserGroup.createUserGroup
     * Documentation: https://api.slack.com/methods/usergroups.create
     * @param options Request options.
     */
    createUserGroup<T = UserGroup.CreateUserGroup.Response.OK>(options: UserGroup.CreateUserGroup.Options): Promise<UserGroup.CreateUserGroup.Response.OK>;
    /**
     * Disable an existing User Group
     * Recommended usage: UserGroup.disableUserGroup
     * Documentation: https://api.slack.com/methods/usergroups.disable
     * @param options Request options.
     */
    disableUserGroup<T = UserGroup.DisableUserGroup.Response.OK>(options: UserGroup.DisableUserGroup.Options): Promise<UserGroup.DisableUserGroup.Response.OK>;
    /**
     * Enable a User Group
     * Recommended usage: UserGroup.enableUserGroup
     * Documentation: https://api.slack.com/methods/usergroups.enable
     * @param options Request options.
     */
    enableUserGroup<T = UserGroup.EnableUserGroup.Response.OK>(options: UserGroup.EnableUserGroup.Options): Promise<UserGroup.EnableUserGroup.Response.OK>;
    /**
     * List all User Groups for a team
     * Recommended usage: UserGroup.getUserGroups
     * Documentation: https://api.slack.com/methods/usergroups.list
     * @param options Request options.
     */
    getUserGroups<T = UserGroup.GetUserGroups.Response.OK>(options?: UserGroup.GetUserGroups.Options): Promise<UserGroup.GetUserGroups.Response.OK>;
    /**
     * Update an existing User Group
     * Recommended usage: UserGroup.updateUserGroup
     * Documentation: https://api.slack.com/methods/usergroups.update
     * @param options Request options.
     */
    updateUserGroup<T = UserGroup.UpdateUserGroup.Response.OK>(options: UserGroup.UpdateUserGroup.Options): Promise<UserGroup.UpdateUserGroup.Response.OK>;
    /**
     * List all users in a User Group
     * Recommended usage: UserGroup.User.getUsers
     * Documentation: https://api.slack.com/methods/usergroups.users.list
     * @param options Request options.
     */
    getUsersInUserGroup<T = UserGroup.User.GetUsers.Response.OK>(options: UserGroup.User.GetUsers.Options): Promise<UserGroup.User.GetUsers.Response.OK>;
    /**
     * Update the list of users for a User Group
     * Recommended usage: UserGroup.User.updateUsers
     * Documentation: https://api.slack.com/methods/usergroups.users.update
     * @param options Request options.
     */
    updateUsersInUserGroup<T = UserGroup.User.UpdateUsers.Response.OK>(options: UserGroup.User.UpdateUsers.Options): Promise<UserGroup.User.UpdateUsers.Response.OK>;
}
declare class AllBotGroup extends BaseGroup {
    constructor(connection: string, options: ConnectionOptions);
    /**
     * Update an existing view.
     * Recommended usage: View.updateView
     * Documentation: https://api.slack.com/methods/views.update
     * @param options Request options.
     */
    updateView<T = View.UpdateView.Response.OK>(options: View.UpdateView.Options): Promise<View.UpdateView.Response.OK>;
    /**
     * Push a view onto the stack of a root view.
     * Recommended usage: View.pushView
     * Documentation: https://api.slack.com/methods/views.push
     * @param options Request options.
     */
    pushView<T = View.PushView.Response.OK>(options: View.PushView.Options): Promise<View.PushView.Response.OK>;
    /**
     * Publish a static view for a User.
     * Recommended usage: View.publishView
     * Documentation: https://api.slack.com/methods/views.publish
     * @param options Request options.
     */
    publishView<T = View.PublishView.Response.OK>(options: View.PublishView.Options): Promise<View.PublishView.Response.OK>;
    /**
     * Open a view for a user.
     * Recommended usage: View.openView
     * Documentation: https://api.slack.com/methods/views.open
     * @param options Request options.
     */
    openView<T = View.OpenView.Response.OK>(options: View.OpenView.Options): Promise<View.OpenView.Response.OK>;
    /**
     * Find a user with an email address.
     * Recommended usage: User.getUserByEmail
     * Documentation: https://api.slack.com/methods/users.lookupByEmail
     * @param options Request options.
     */
    getUserByEmail<T = User.GetUserByEmail.Response.OK>(options: User.GetUserByEmail.Options): Promise<User.GetUserByEmail.Response.OK>;
    /**
     * Lists all users in a Slack team.
     * Recommended usage: User.getUsers
     * Documentation: https://api.slack.com/methods/users.list
     * @param options Request options.
     */
    getUsers<T = User.GetUsers.Response.OK>(options?: User.GetUsers.Options): Promise<User.GetUsers.Response.OK>;
    /**
     * Gets information about a user.
     * Recommended usage: User.getInfo
     * Documentation: https://api.slack.com/methods/users.info
     * @param options Request options.
     */
    getUserInfo<T = User.GetInfo.Response.OK>(options: User.GetInfo.Options): Promise<User.GetInfo.Response.OK>;
    /**
     * List conversations the calling user may access.
     * Recommended usage: User.getConversations
     * Documentation: https://api.slack.com/methods/users.conversations
     * @param options Request options.
     */
    getUserConversations<T = User.GetConversations.Response.OK>(options?: User.GetConversations.Options): Promise<User.GetConversations.Response.OK>;
    /**
     * Gets user presence information.
     * Recommended usage: User.getPresence
     * Documentation: https://api.slack.com/methods/users.getPresence
     * @param options Request options.
     */
    getUserPresence<T = User.GetPresence.Response.OK>(options?: User.GetPresence.Options): Promise<User.GetPresence.Response.OK>;
    /**
     * Manually sets user presence.
     * Recommended usage: User.setPresence
     * Documentation: https://api.slack.com/methods/users.setPresence
     * @param options Request options.
     */
    setUserPresence<T = User.SetPresence.Response.OK>(options: User.SetPresence.Options): Promise<User.SetPresence.Response.OK>;
    /**
     * Retrieves a user's profile information.
     * Recommended usage: User.Profile.getProfile
     * Documentation: https://api.slack.com/methods/users.profile.get
     * @param options Request options.
     */
    getUserProfile<T = User.Profile.GetProfile.Response.OK>(options?: User.Profile.GetProfile.Options): Promise<User.Profile.GetProfile.Response.OK>;
    /**
     * Un-pins an item from a channel.
     * Recommended usage: Pins.removePin
     * Documentation: https://api.slack.com/methods/pins.remove
     * @param options Request options.
     */
    removePin<T = Pins.RemovePin.Response.OK>(options: Pins.RemovePin.Options): Promise<Pins.RemovePin.Response.OK>;
    /**
     * Lists items pinned to a channel.
     * Recommended usage: Pins.getPins
     * Documentation: https://api.slack.com/methods/pins.list
     * @param options Request options.
     */
    getPins<T = Pins.GetPins.Response.OK>(options: Pins.GetPins.Options): Promise<any>;
    /**
     * Pins an item to a channel.
     * Recommended usage: Pins.addPin
     * Documentation: https://api.slack.com/methods/pins.add
     * @param options Request options.
     */
    addPin<T = Pins.AddPin.Response.OK>(options: Pins.AddPin.Options): Promise<Pins.AddPin.Response.OK>;
    /**
     * Gets information about a bot user.
     * Recommended usage: Bot.getInfo
     * Documentation: https://api.slack.com/methods/bots.info
     * @param options Request options.
     */
    getBotInfo<T = Bot.GetInfo.Response.OK>(options?: Bot.GetInfo.Options): Promise<Bot.GetInfo.Response.OK>;
    /**
     * Deletes a message.
     * Recommended usage: Chat.deleteMessage
     * Documentation: https://api.slack.com/methods/chat.delete
     * @param options Request options.
     */
    deleteChatMessage<T = Chat.DeleteMessage.Response.OK>(options: Chat.DeleteMessage.Options): Promise<Chat.DeleteMessage.Response.OK>;
    /**
     * Deletes a pending scheduled message from the queue.
     * Recommended usage: Chat.deleteScheduledMessage
     * Documentation: https://api.slack.com/methods/chat.deleteScheduledMessage
     * @param options Request options.
     */
    deleteChatScheduledMessage<T = Chat.DeleteScheduledMessage.Response.OK>(options: Chat.DeleteScheduledMessage.Options): Promise<Chat.DeleteScheduledMessage.Response.OK>;
    /**
     * Retrieve a permalink URL for a specific extant message
     * Recommended usage: Chat.getPermalink
     * Documentation: https://api.slack.com/methods/chat.getPermalink
     * @param options Request options.
     */
    getChatPermalink<T = Chat.GetPermalink.Response.OK>(options: Chat.GetPermalink.Options): Promise<Chat.GetPermalink.Response.OK>;
    /**
     * Share a me message into a channel.
     * Recommended usage: Chat.postMeMessage
     * Documentation: https://api.slack.com/methods/chat.meMessage
     * @param options Request options.
     */
    postChatMeMessage<T = Chat.PostMeMessage.Response.OK>(options: Chat.PostMeMessage.Options): Promise<Chat.PostMeMessage.Response.OK>;
    /**
     * Sends an ephemeral message to a user in a channel.
     * Recommended usage: Chat.postEphemeralMessage
     * Documentation: https://api.slack.com/methods/chat.postEphemeral
     * @param options Request options.
     */
    postChatEphemeralMessage<T = Chat.PostEphemeralMessage.Response.OK>(options: Chat.PostEphemeralMessage.Options): Promise<Chat.PostEphemeralMessage.Response.OK>;
    /**
     * Sends a message to a channel.
     * Recommended usage: Chat.postMessage
     * Documentation: https://api.slack.com/methods/chat.postMessage
     * @param options Request options.
     */
    postChatMessage<T = Chat.PostMessage.Response.OK>(options: Chat.PostMessage.Options): Promise<Chat.PostMessage.Response.OK>;
    /**
     * Schedules a message to be sent to a channel.
     * Recommended usage: Chat.scheduleMessage
     * Documentation: https://api.slack.com/methods/chat.scheduleMessage
     * @param options Request options.
     */
    scheduleChatMessage<T = Chat.ScheduleMessage.Response.OK>(options: Chat.ScheduleMessage.Options): Promise<Chat.ScheduleMessage.Response.OK>;
    /**
     * Provide custom unfurl behavior for user-posted URLs
     * Recommended usage: Chat.unfurlMessage
     * Documentation: https://api.slack.com/methods/chat.unfurl
     * @param options Request options.
     */
    unfurlChatMessage<T = Chat.UnfurlMessage.Response.OK>(options: Chat.UnfurlMessage.Options): Promise<Chat.UnfurlMessage.Response.OK>;
    /**
     * Updates a message.
     * Recommended usage: Chat.updateMessage
     * Documentation: https://api.slack.com/methods/chat.update
     * @param options Request options.
     */
    updateChatMessage<T = Chat.UpdateMessage.Response.OK>(options: Chat.UpdateMessage.Options): Promise<Chat.UpdateMessage.Response.OK>;
    /**
     * Returns a list of scheduled messages.
     * Recommended usage: Chat.ScheduledMessage.getScheduledMessages
     * Documentation: https://api.slack.com/methods/chat.scheduledMessages.list
     * @param options Request options.
     */
    getChatScheduledMessages<T = Chat.ScheduledMessage.GetScheduledMessages.Response.OK>(options?: Chat.ScheduledMessage.GetScheduledMessages.Options): Promise<Chat.ScheduledMessage.GetScheduledMessages.Response.OK>;
    /**
     * Archives a conversation.
     * Recommended usage: Conversation.archiveConversation
     * Documentation: https://api.slack.com/methods/conversations.archive
     * @param options Request options.
     */
    archiveConversation<T = Conversation.ArchiveConversation.Response.OK>(options: Conversation.ArchiveConversation.Options): Promise<Conversation.ArchiveConversation.Response.OK>;
    /**
     * Closes a direct message or multi-person direct message.
     * Recommended usage: Conversation.closeConversation
     * Documentation: https://api.slack.com/methods/conversations.close
     * @param options Request options.
     */
    closeConversation<T = Conversation.CloseConversation.Response.OK>(options: Conversation.CloseConversation.Options): Promise<Conversation.CloseConversation.Response.OK>;
    /**
     * Initiates a public or private channel-based conversation
     * Recommended usage: Conversation.createConversation
     * Documentation: https://api.slack.com/methods/conversations.create
     * @param options Request options.
     */
    createConversation<T = Conversation.CreateConversation.Response.OK>(options: Conversation.CreateConversation.Options): Promise<Conversation.CreateConversation.Response.OK>;
    /**
     * Fetches a conversation's history of messages and events.
     * Recommended usage: Conversation.getHistory
     * Documentation: https://api.slack.com/methods/conversations.history
     * @param options Request options.
     */
    getConversationHistory<T = Conversation.GetHistory.Response.OK>(options?: Conversation.GetHistory.Options): Promise<Conversation.GetHistory.Response.OK>;
    /**
     * Retrieve information about a conversation.
     * Recommended usage: Conversation.getInfo
     * Documentation: https://api.slack.com/methods/conversations.info
     * @param options Request options.
     */
    getConversationInfo<T = Conversation.GetInfo.Response.OK>(options: Conversation.GetInfo.Options): Promise<Conversation.GetInfo.Response.OK>;
    /**
     * Invites users to a channel.
     * Recommended usage: Conversation.inviteUser
     * Documentation: https://api.slack.com/methods/conversations.invite
     * @param options Request options.
     */
    inviteUserToConversation<T = Conversation.InviteUser.Response.OK>(options: Conversation.InviteUser.Options): Promise<Conversation.InviteUser.Response.OK>;
    /**
     * Joins an existing conversation.
     * Recommended usage: Conversation.joinConversation
     * Documentation: https://api.slack.com/methods/conversations.join
     * @param options Request options.
     */
    joinConversation<T = Conversation.JoinConversation.Response.OK>(options: Conversation.JoinConversation.Options): Promise<Conversation.JoinConversation.Response.OK>;
    /**
     * Removes a user from a conversation.
     * Recommended usage: Conversation.kickUser
     * Documentation: https://api.slack.com/methods/conversations.kick
     * @param options Request options.
     */
    kickUserFromConversation<T = Conversation.KickUser.Response.OK>(options: Conversation.KickUser.Options): Promise<Conversation.KickUser.Response.OK>;
    /**
     * Leaves a conversation.
     * Recommended usage: Conversation.leaveConversation
     * Documentation: https://api.slack.com/methods/conversations.leave
     * @param options Request options.
     */
    leaveConversation<T = Conversation.LeaveConversation.Response.OK>(options: Conversation.LeaveConversation.Options): Promise<Conversation.LeaveConversation.Response.OK>;
    /**
     * Lists all channels in a Slack team.
     * Recommended usage: Conversation.getConversations
     * Documentation: https://api.slack.com/methods/conversations.list
     * @param options Request options.
     */
    getConversations<T = Conversation.GetConversations.Response.OK>(options?: Conversation.GetConversations.Options): Promise<Conversation.GetConversations.Response.OK>;
    /**
     * Retrieve members of a conversation.
     * Recommended usage: Conversation.getMembers
     * Documentation: https://api.slack.com/methods/conversations.members
     * @param options Request options.
     */
    getConversationMembers<T = Conversation.GetMembers.Response.OK>(options: Conversation.GetMembers.Options): Promise<Conversation.GetMembers.Response.OK>;
    /**
     * Opens or resumes a direct message or multi-person direct message.
     * Recommended usage: Conversation.openConversation
     * Documentation: https://api.slack.com/methods/conversations.open
     * @param options Request options.
     */
    openConversation<T = Conversation.OpenConversation.Response.OK>(options: Conversation.OpenConversation.Options): Promise<Conversation.OpenConversation.Response.OK>;
    /**
     * Renames a conversation.
     * Recommended usage: Conversation.renameConversation
     * Documentation: https://api.slack.com/methods/conversations.rename
     * @param options Request options.
     */
    renameConversation<T = Conversation.RenameConversation.Response.OK>(options: Conversation.RenameConversation.Options): Promise<Conversation.RenameConversation.Response.OK>;
    /**
     * Retrieve a thread of messages posted to a conversation
     * Recommended usage: Conversation.getReplies
     * Documentation: https://api.slack.com/methods/conversations.replies
     * @param options Request options.
     */
    getConversationReplies<T = Conversation.GetReplies.Response.OK>(options?: Conversation.GetReplies.Options): Promise<Conversation.GetReplies.Response.OK>;
    /**
     * Sets the purpose for a conversation.
     * Recommended usage: Conversation.setPurpose
     * Documentation: https://api.slack.com/methods/conversations.setPurpose
     * @param options Request options.
     */
    setConversationPurpose<T = Conversation.SetPurpose.Response.OK>(options: Conversation.SetPurpose.Options): Promise<Conversation.SetPurpose.Response.OK>;
    /**
     * Sets the topic for a conversation.
     * Recommended usage: Conversation.setTopic
     * Documentation: https://api.slack.com/methods/conversations.setTopic
     * @param options Request options.
     */
    setConversationTopic<T = Conversation.SetTopic.Response.OK>(options: Conversation.SetTopic.Options): Promise<Conversation.SetTopic.Response.OK>;
    /**
     * Reverses conversation archival.
     * Recommended usage: Conversation.unarchiveConversation
     * Documentation: https://api.slack.com/methods/conversations.unarchive
     * @param options Request options.
     */
    unarchiveConversation<T = Conversation.UnarchiveConversation.Response.OK>(options: Conversation.UnarchiveConversation.Options): Promise<Conversation.UnarchiveConversation.Response.OK>;
    /**
     * Open a dialog with a user
     * Recommended usage: Dialog.openDialog
     * Documentation: https://api.slack.com/methods/dialog.open
     * @param options Request options.
     */
    openDialog<T = Dialog.OpenDialog.Response.OK>(options: Dialog.OpenDialog.Options): Promise<Dialog.OpenDialog.Response.OK>;
    /**
     * Retrieves a user's current Do Not Disturb status.
     * Recommended usage: Dnd.getInfo
     * Documentation: https://api.slack.com/methods/dnd.info
     * @param options Request options.
     */
    getDndInfo<T = Dnd.GetInfo.Response.OK>(options?: Dnd.GetInfo.Options): Promise<Dnd.GetInfo.Response.OK>;
    /**
     * Retrieves the Do Not Disturb status for up to 50 users on a team.
     * Recommended usage: Dnd.getTeamInfo
     * Documentation: https://api.slack.com/methods/dnd.teamInfo
     * @param options Request options.
     */
    getDndTeamInfo<T = Dnd.GetTeamInfo.Response.OK>(options: Dnd.GetTeamInfo.Options): Promise<Dnd.GetTeamInfo.Response.OK>;
    /**
     * Lists custom emoji for a team.
     * Recommended usage: Emoji.getEmojis
     * Documentation: https://api.slack.com/methods/emoji.list
     * @param options Request options.
     */
    getEmojis<T = Emoji.GetEmojis.Response.OK>(options?: Emoji.GetEmojis.Options): Promise<Emoji.GetEmojis.Response.OK>;
    /**
     * Deletes a file.
     * Recommended usage: File.deleteFile
     * Documentation: https://api.slack.com/methods/files.delete
     * @param options Request options.
     */
    deleteFile<T = File.DeleteFile.Response.OK>(options: File.DeleteFile.Options): Promise<File.DeleteFile.Response.OK>;
    /**
     * Gets information about a file.
     * Recommended usage: File.getInfo
     * Documentation: https://api.slack.com/methods/files.info
     * @param options Request options.
     */
    getFileInfo<T = File.GetInfo.Response.OK>(options?: File.GetInfo.Options): Promise<File.GetInfo.Response.OK>;
    /**
     * List for a team, in a channel, or from a user with applied filters.
     * Recommended usage: File.getFiles
     * Documentation: https://api.slack.com/methods/files.list
     * @param options Request options.
     */
    getFiles<T = File.GetFiles.Response.OK>(options?: File.GetFiles.Options): Promise<File.GetFiles.Response.OK>;
    /**
     * Uploads or creates a file.
     * Recommended usage: File.uploadFile
     * Documentation: https://api.slack.com/methods/files.upload
     * @param options Request options.
     */
    uploadFile<T = File.UploadFile.Response.OK>(options: File.UploadFile.Options): Promise<File.UploadFile.Response.OK>;
    /**
     * Deletes an existing comment on a file.
     * Recommended usage: File.Comment.deleteComment
     * Documentation: https://api.slack.com/methods/files.comments.delete
     * @param options Request options.
     */
    deleteFileComment<T = File.Comment.DeleteComment.Response.OK>(options: File.Comment.DeleteComment.Options): Promise<File.Comment.DeleteComment.Response.OK>;
    /**
     * Adds a file from a remote service
     * Recommended usage: File.Remote.addFile
     * Documentation: https://api.slack.com/methods/files.remote.add
     * @param options Request options.
     */
    addRemoteFile<T = File.Remote.AddFile.Response.OK>(options: File.Remote.AddFile.Options): Promise<File.Remote.AddFile.Response.OK>;
    /**
     * Retrieve information about a remote file added to Slack
     * Recommended usage: File.Remote.getInfo
     * Documentation: https://api.slack.com/methods/files.remote.info
     * @param options Request options.
     */
    getRemoteFileInfo<T = File.Remote.GetInfo.Response.OK>(options?: File.Remote.GetInfo.Options): Promise<File.Remote.GetInfo.Response.OK>;
    /**
     * Retrieve information about a remote file added to Slack
     * Recommended usage: File.Remote.getFiles
     * Documentation: https://api.slack.com/methods/files.remote.list
     * @param options Request options.
     */
    getRemoteFiles<T = File.Remote.GetFiles.Response.OK>(options?: File.Remote.GetFiles.Options): Promise<File.Remote.GetFiles.Response.OK>;
    /**
     * Remove a remote file.
     * Recommended usage: File.Remote.removeFile
     * Documentation: https://api.slack.com/methods/files.remote.remove
     * @param options Request options.
     */
    removeRemoteFile<T = File.Remote.RemoveFile.Response.OK>(options?: File.Remote.RemoveFile.Options): Promise<File.Remote.RemoveFile.Response.OK>;
    /**
     * Share a remote file into a channel.
     * Recommended usage: File.Remote.shareFile
     * Documentation: https://api.slack.com/methods/files.remote.share
     * @param options Request options.
     */
    shareRemoteFile<T = File.Remote.ShareFile.Response.OK>(options?: File.Remote.ShareFile.Options): Promise<File.Remote.ShareFile.Response.OK>;
    /**
     * Updates an existing remote file.
     * Recommended usage: File.Remote.updateFile
     * Documentation: https://api.slack.com/methods/files.remote.update
     * @param options Request options.
     */
    updateRemoteFile<T = File.Remote.UpdateFile.Response.OK>(options?: File.Remote.UpdateFile.Options): Promise<File.Remote.UpdateFile.Response.OK>;
    /**
     * Adds a reaction to an item.
     * Recommended usage: Reaction.addReaction
     * Documentation: https://api.slack.com/methods/reactions.add
     * @param options Request options.
     */
    addReaction<T = Reaction.AddReaction.Response.OK>(options: Reaction.AddReaction.Options): Promise<Reaction.AddReaction.Response.OK>;
    /**
     * Gets reactions for an item.
     * Recommended usage: Reaction.getReaction
     * Documentation: https://api.slack.com/methods/reactions.get
     * @param options Request options.
     */
    getReaction<T = Reaction.GetReaction.Response.OK>(options?: Reaction.GetReaction.Options): Promise<Reaction.GetReaction.Response.OK>;
    /**
     * Lists reactions made by a user.
     * Recommended usage: Reaction.getReactions
     * Documentation: https://api.slack.com/methods/reactions.list
     * @param options Request options.
     */
    getReactions<T = Reaction.GetReactions.Response.OK>(options?: Reaction.GetReactions.Options): Promise<Reaction.GetReactions.Response.OK>;
    /**
     * Removes a reaction from an item.
     * Recommended usage: Reaction.removeReaction
     * Documentation: https://api.slack.com/methods/reactions.remove
     * @param options Request options.
     */
    removeReaction<T = Reaction.RemoveReaction.Response.OK>(options: Reaction.RemoveReaction.Options): Promise<Reaction.RemoveReaction.Response.OK>;
    /**
     * Gets information about the current team.
     * Recommended usage: Team.getInfo
     * Documentation: https://api.slack.com/methods/team.info
     * @param options Request options.
     */
    getTeamInfo<T = Team.GetInfo.Response.OK>(options?: Team.GetInfo.Options): Promise<Team.GetInfo.Response.OK>;
    /**
     * Retrieve a team's profile.
     * Recommended usage: Team.Profile.getProfile
     * Documentation: https://api.slack.com/methods/team.profile.get
     * @param options Request options.
     */
    getTeamProfile<T = Team.Profile.GetProfile.Response.OK>(options?: Team.Profile.GetProfile.Options): Promise<Team.Profile.GetProfile.Response.OK>;
    /**
     * Create a User Group
     * Recommended usage: UserGroup.createUserGroup
     * Documentation: https://api.slack.com/methods/usergroups.create
     * @param options Request options.
     */
    createUserGroup<T = UserGroup.CreateUserGroup.Response.OK>(options: UserGroup.CreateUserGroup.Options): Promise<UserGroup.CreateUserGroup.Response.OK>;
    /**
     * Disable an existing User Group
     * Recommended usage: UserGroup.disableUserGroup
     * Documentation: https://api.slack.com/methods/usergroups.disable
     * @param options Request options.
     */
    disableUserGroup<T = UserGroup.DisableUserGroup.Response.OK>(options: UserGroup.DisableUserGroup.Options): Promise<UserGroup.DisableUserGroup.Response.OK>;
    /**
     * Enable a User Group
     * Recommended usage: UserGroup.enableUserGroup
     * Documentation: https://api.slack.com/methods/usergroups.enable
     * @param options Request options.
     */
    enableUserGroup<T = UserGroup.EnableUserGroup.Response.OK>(options: UserGroup.EnableUserGroup.Options): Promise<UserGroup.EnableUserGroup.Response.OK>;
    /**
     * List all User Groups for a team
     * Recommended usage: UserGroup.getUserGroups
     * Documentation: https://api.slack.com/methods/usergroups.list
     * @param options Request options.
     */
    getUserGroups<T = UserGroup.GetUserGroups.Response.OK>(options?: UserGroup.GetUserGroups.Options): Promise<UserGroup.GetUserGroups.Response.OK>;
    /**
     * Update an existing User Group
     * Recommended usage: UserGroup.updateUserGroup
     * Documentation: https://api.slack.com/methods/usergroups.update
     * @param options Request options.
     */
    updateUserGroup<T = UserGroup.UpdateUserGroup.Response.OK>(options: UserGroup.UpdateUserGroup.Options): Promise<UserGroup.UpdateUserGroup.Response.OK>;
    /**
     * List all users in a User Group
     * Recommended usage: UserGroup.User.getUsers
     * Documentation: https://api.slack.com/methods/usergroups.users.list
     * @param options Request options.
     */
    getUsersInUserGroup<T = UserGroup.User.GetUsers.Response.OK>(options: UserGroup.User.GetUsers.Options): Promise<UserGroup.User.GetUsers.Response.OK>;
    /**
     * Update the list of users for a User Group
     * Recommended usage: UserGroup.User.updateUsers
     * Documentation: https://api.slack.com/methods/usergroups.users.update
     * @param options Request options.
     */
    updateUsersInUserGroup<T = UserGroup.User.UpdateUsers.Response.OK>(options: UserGroup.User.UpdateUsers.Options): Promise<UserGroup.User.UpdateUsers.Response.OK>;
}
export {};
//# sourceMappingURL=index.d.ts.map