import { httpPost } from "../raw-api/common";
import { httpGet } from "../raw-api/common";
import { constructUrl } from "@avst-api/commons";
/**
 * Archives a conversation.
 * Documentation: https://api.slack.com/methods/conversations.archive
 * @param options Request options.
 */
export function archiveConversation(options) {
    const { connectionId: instanceId, headers, body, preferredAuth, userId } = options;
    const customParams = { preferredAuth, userId };
    return httpPost(instanceId, `/api/conversations.archive`, body, headers, customParams);
}
/**
 * Closes a direct message or multi-person direct message.
 * Documentation: https://api.slack.com/methods/conversations.close
 * @param options Request options.
 */
export function closeConversation(options) {
    const { connectionId: instanceId, headers, body, preferredAuth, userId } = options;
    const customParams = { preferredAuth, userId };
    return httpPost(instanceId, `/api/conversations.close`, body, headers, customParams);
}
/**
 * Initiates a public or private channel-based conversation
 * Documentation: https://api.slack.com/methods/conversations.create
 * @param options Request options.
 */
export function createConversation(options) {
    const { connectionId: instanceId, headers, body, preferredAuth, userId } = options;
    const customParams = { preferredAuth, userId };
    return httpPost(instanceId, `/api/conversations.create`, body, headers, customParams);
}
/**
 * Fetches a conversation's history of messages and events.
 * Documentation: https://api.slack.com/methods/conversations.history
 * @param options Request options.
 */
export function getConversationHistory(options) {
    const { connectionId: instanceId, headers, channel, latest, oldest, inclusive, limit, cursor, preferredAuth, userId } = options;
    const queryParams = { channel, latest, oldest, inclusive, limit, cursor };
    const customParams = { preferredAuth, userId };
    return httpGet(instanceId, constructUrl(`/api/conversations.history`, queryParams), headers, customParams);
}
/**
 * Retrieve information about a conversation.
 * Documentation: https://api.slack.com/methods/conversations.info
 * @param options Request options.
 */
export function getConversationInfo(options) {
    const { connectionId: instanceId, headers, channel, include_locale, include_num_members, preferredAuth, userId } = options;
    const queryParams = { channel, include_locale, include_num_members };
    const customParams = { preferredAuth, userId };
    return httpGet(instanceId, constructUrl(`/api/conversations.info`, queryParams), headers, customParams);
}
/**
 * Invites users to a channel.
 * Documentation: https://api.slack.com/methods/conversations.invite
 * @param options Request options.
 */
export function inviteUserToConversation(options) {
    const { connectionId: instanceId, headers, body, preferredAuth, userId } = options;
    const customParams = { preferredAuth, userId };
    return httpPost(instanceId, `/api/conversations.invite`, body, headers, customParams);
}
/**
 * Joins an existing conversation.
 * Documentation: https://api.slack.com/methods/conversations.join
 * @param options Request options.
 */
export function joinConversation(options) {
    const { connectionId: instanceId, headers, body, preferredAuth, userId } = options;
    const customParams = { preferredAuth, userId };
    return httpPost(instanceId, `/api/conversations.join`, body, headers, customParams);
}
/**
 * Removes a user from a conversation.
 * Documentation: https://api.slack.com/methods/conversations.kick
 * @param options Request options.
 */
export function kickUserFromConversation(options) {
    const { connectionId: instanceId, headers, body, preferredAuth, userId } = options;
    const customParams = { preferredAuth, userId };
    return httpPost(instanceId, `/api/conversations.kick`, body, headers, customParams);
}
/**
 * Leaves a conversation.
 * Documentation: https://api.slack.com/methods/conversations.leave
 * @param options Request options.
 */
export function leaveConversation(options) {
    const { connectionId: instanceId, headers, body, preferredAuth, userId } = options;
    const customParams = { preferredAuth, userId };
    return httpPost(instanceId, `/api/conversations.leave`, body, headers, customParams);
}
/**
 * Lists all channels in a Slack team.
 * Documentation: https://api.slack.com/methods/conversations.list
 * @param options Request options.
 */
export function getConversations(options) {
    const { connectionId: instanceId, headers, exclude_archived, types, limit, cursor, preferredAuth, userId } = options;
    const queryParams = { exclude_archived, types, limit, cursor };
    const customParams = { preferredAuth, userId };
    return httpGet(instanceId, constructUrl(`/api/conversations.list`, queryParams), headers, customParams);
}
/**
 * Retrieve members of a conversation.
 * Documentation: https://api.slack.com/methods/conversations.members
 * @param options Request options.
 */
export function getConversationMembers(options) {
    const { connectionId: instanceId, headers, channel, limit, cursor, preferredAuth, userId } = options;
    const queryParams = { channel, limit, cursor };
    const customParams = { preferredAuth, userId };
    return httpGet(instanceId, constructUrl(`/api/conversations.members`, queryParams), headers, customParams);
}
/**
 * Opens or resumes a direct message or multi-person direct message.
 * Documentation: https://api.slack.com/methods/conversations.open
 * @param options Request options.
 */
export function openConversation(options) {
    const { connectionId: instanceId, headers, body, preferredAuth, userId } = options;
    const customParams = { preferredAuth, userId };
    return httpPost(instanceId, `/api/conversations.open`, body, headers, customParams);
}
/**
 * Renames a conversation.
 * Documentation: https://api.slack.com/methods/conversations.rename
 * @param options Request options.
 */
export function renameConversation(options) {
    const { connectionId: instanceId, headers, body, preferredAuth, userId } = options;
    const customParams = { preferredAuth, userId };
    return httpPost(instanceId, `/api/conversations.rename`, body, headers, customParams);
}
/**
 * Retrieve a thread of messages posted to a conversation
 * Documentation: https://api.slack.com/methods/conversations.replies
 * @param options Request options.
 */
export function getConversationReplies(options) {
    const { connectionId: instanceId, headers, channel, ts, latest, oldest, inclusive, limit, cursor, preferredAuth, userId } = options;
    const queryParams = { channel, ts, latest, oldest, inclusive, limit, cursor };
    const customParams = { preferredAuth, userId };
    return httpGet(instanceId, constructUrl(`/api/conversations.replies`, queryParams), headers, customParams);
}
/**
 * Sets the purpose for a conversation.
 * Documentation: https://api.slack.com/methods/conversations.setPurpose
 * @param options Request options.
 */
export function setConversationPurpose(options) {
    const { connectionId: instanceId, headers, body, preferredAuth, userId } = options;
    const customParams = { preferredAuth, userId };
    return httpPost(instanceId, `/api/conversations.setPurpose`, body, headers, customParams);
}
/**
 * Sets the topic for a conversation.
 * Documentation: https://api.slack.com/methods/conversations.setTopic
 * @param options Request options.
 */
export function setConversationTopic(options) {
    const { connectionId: instanceId, headers, body, preferredAuth, userId } = options;
    const customParams = { preferredAuth, userId };
    return httpPost(instanceId, `/api/conversations.setTopic`, body, headers, customParams);
}
/**
 * Reverses conversation archival.
 * Documentation: https://api.slack.com/methods/conversations.unarchive
 * @param options Request options.
 */
export function unarchiveConversation(options) {
    const { connectionId: instanceId, headers, body, preferredAuth, userId } = options;
    const customParams = { preferredAuth, userId };
    return httpPost(instanceId, `/api/conversations.unarchive`, body, headers, customParams);
}
